@@ -13,13 +13,8 @@ from ...types import UNSET, Response, Unset
 
 def _get_kwargs(
   *,
-  authorization: Union[None, Unset, str] = UNSET,
   auth_token: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
   cookies = {}
   if auth_token is not UNSET:
     cookies["auth-token"] = auth_token
@@ -30,7 +25,6 @@ def _get_kwargs(
     "cookies": cookies,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -41,14 +35,17 @@ def _parse_response(
     response_200 = SSOTokenResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 401:
     response_401 = ErrorResponse.from_dict(response.json())
 
     return response_401
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -69,7 +66,6 @@ def _build_response(
 def sync_detailed(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
   auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SSOTokenResponse]]:
   """Generate SSO Token
@@ -77,7 +73,6 @@ def sync_detailed(
    Generate a temporary SSO token for cross-app authentication.
 
   Args:
-      authorization (Union[None, Unset, str]):
       auth_token (Union[None, Unset, str]):
 
   Raises:
@@ -89,7 +84,6 @@ def sync_detailed(
   """
 
   kwargs = _get_kwargs(
-    authorization=authorization,
     auth_token=auth_token,
   )
 
@@ -103,7 +97,6 @@ def sync_detailed(
 def sync(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
   auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SSOTokenResponse]]:
   """Generate SSO Token
@@ -111,7 +104,6 @@ def sync(
    Generate a temporary SSO token for cross-app authentication.
 
   Args:
-      authorization (Union[None, Unset, str]):
       auth_token (Union[None, Unset, str]):
 
   Raises:
@@ -124,7 +116,6 @@ def sync(
 
   return sync_detailed(
     client=client,
-    authorization=authorization,
     auth_token=auth_token,
   ).parsed
 
@@ -132,7 +123,6 @@ def sync(
 async def asyncio_detailed(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
   auth_token: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SSOTokenResponse]]:
   """Generate SSO Token
@@ -140,7 +130,6 @@ async def asyncio_detailed(
    Generate a temporary SSO token for cross-app authentication.
 
   Args:
-      authorization (Union[None, Unset, str]):
       auth_token (Union[None, Unset, str]):
 
   Raises:
@@ -152,7 +141,6 @@ async def asyncio_detailed(
   """
 
   kwargs = _get_kwargs(
-    authorization=authorization,
     auth_token=auth_token,
   )
 
@@ -164,7 +152,6 @@ async def asyncio_detailed(
 async def asyncio(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
   auth_token: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SSOTokenResponse]]:
   """Generate SSO Token
@@ -172,7 +159,6 @@ async def asyncio(
    Generate a temporary SSO token for cross-app authentication.
 
   Args:
-      authorization (Union[None, Unset, str]):
       auth_token (Union[None, Unset, str]):
 
   Raises:
@@ -186,7 +172,6 @@ async def asyncio(
   return (
     await asyncio_detailed(
       client=client,
-      authorization=authorization,
       auth_token=auth_token,
     )
   ).parsed
