@@ -9,48 +9,33 @@ from ...models.error_response import ErrorResponse
 from ...models.get_current_auth_user_response_getcurrentauthuser import (
   GetCurrentAuthUserResponseGetcurrentauthuser,
 )
-from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
-def _get_kwargs(
-  *,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
+def _get_kwargs() -> dict[str, Any]:
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": "/v1/auth/me",
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
 def _parse_response(
   *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[
-  Union[
-    ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError
-  ]
-]:
+) -> Optional[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]:
   if response.status_code == 200:
     response_200 = GetCurrentAuthUserResponseGetcurrentauthuser.from_dict(
       response.json()
     )
 
     return response_200
+
   if response.status_code == 401:
     response_401 = ErrorResponse.from_dict(response.json())
 
     return response_401
-  if response.status_code == 422:
-    response_422 = HTTPValidationError.from_dict(response.json())
 
-    return response_422
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -59,11 +44,7 @@ def _parse_response(
 
 def _build_response(
   *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[
-  Union[
-    ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError
-  ]
-]:
+) -> Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]:
   return Response(
     status_code=HTTPStatus(response.status_code),
     content=response.content,
@@ -75,30 +56,20 @@ def _build_response(
 def sync_detailed(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Response[
-  Union[
-    ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError
-  ]
-]:
+) -> Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]:
   """Get Current User
 
    Get the currently authenticated user.
 
-  Args:
-      authorization (Union[None, Unset, str]):
-
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError]]
+      Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]
   """
 
-  kwargs = _get_kwargs(
-    authorization=authorization,
-  )
+  kwargs = _get_kwargs()
 
   response = client.get_httpx_client().request(
     **kwargs,
@@ -110,60 +81,41 @@ def sync_detailed(
 def sync(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Optional[
-  Union[
-    ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError
-  ]
-]:
+) -> Optional[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]:
   """Get Current User
 
    Get the currently authenticated user.
 
-  Args:
-      authorization (Union[None, Unset, str]):
-
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError]
+      Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]
   """
 
   return sync_detailed(
     client=client,
-    authorization=authorization,
   ).parsed
 
 
 async def asyncio_detailed(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Response[
-  Union[
-    ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError
-  ]
-]:
+) -> Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]:
   """Get Current User
 
    Get the currently authenticated user.
 
-  Args:
-      authorization (Union[None, Unset, str]):
-
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError]]
+      Response[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]
   """
 
-  kwargs = _get_kwargs(
-    authorization=authorization,
-  )
+  kwargs = _get_kwargs()
 
   response = await client.get_async_httpx_client().request(**kwargs)
 
@@ -173,30 +125,21 @@ async def asyncio_detailed(
 async def asyncio(
   *,
   client: Union[AuthenticatedClient, Client],
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Optional[
-  Union[
-    ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError
-  ]
-]:
+) -> Optional[Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]]:
   """Get Current User
 
    Get the currently authenticated user.
 
-  Args:
-      authorization (Union[None, Unset, str]):
-
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser, HTTPValidationError]
+      Union[ErrorResponse, GetCurrentAuthUserResponseGetcurrentauthuser]
   """
 
   return (
     await asyncio_detailed(
       client=client,
-      authorization=authorization,
     )
   ).parsed
