@@ -8,35 +8,19 @@ from ...client import AuthenticatedClient, Client
 from ...models.backup_create_request import BackupCreateRequest
 from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
   *,
   body: BackupCreateRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
     "url": f"/v1/graphs/{graph_id}/backups",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -53,26 +37,32 @@ def _parse_response(
   if response.status_code == 202:
     response_202 = response.json()
     return response_202
+
   if response.status_code == 400:
     response_400 = ErrorResponse.from_dict(response.json())
 
     return response_400
+
   if response.status_code == 403:
     response_403 = ErrorResponse.from_dict(response.json())
 
     return response_403
+
   if response.status_code == 404:
     response_404 = ErrorResponse.from_dict(response.json())
 
     return response_404
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -95,14 +85,12 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: BackupCreateRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Create Backup
 
    Create a backup of the graph database.
 
-  Creates a complete backup of the Kuzu database (.kuzu file) with:
+  Creates a complete backup of the graph database (.kuzu file) with:
   - **Format**: Full database backup only (complete .kuzu file)
   - **Compression**: Always enabled for optimal storage
   - **Encryption**: Optional AES-256 encryption for security
@@ -114,6 +102,23 @@ def sync_detailed(
   - **Download Support**: Unencrypted backups can be downloaded
   - **Restore Support**: Future support for encrypted backup restoration
 
+  **Operation State Machine:**
+  ```
+  pending → processing → completed
+                      ↘ failed
+  ```
+  - **pending**: Backup queued, waiting to start
+  - **processing**: Actively backing up database
+  - **completed**: Backup successfully created and stored
+  - **failed**: Backup failed (check error message)
+
+  **Expected Durations:**
+  Operation times vary by database size:
+  - **Small** (<1GB): 30 seconds - 2 minutes
+  - **Medium** (1-10GB): 2-10 minutes
+  - **Large** (10-100GB): 10-30 minutes
+  - **Very Large** (>100GB): 30+ minutes
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -121,6 +126,7 @@ def sync_detailed(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Backup progress:', data.progress_percent + '%');
+    console.log('Status:', data.status); // pending, processing, completed, failed
   });
   ```
 
@@ -144,9 +150,7 @@ def sync_detailed(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (BackupCreateRequest): Request model for creating a backup.
 
   Raises:
@@ -160,8 +164,6 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -176,14 +178,12 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: BackupCreateRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Create Backup
 
    Create a backup of the graph database.
 
-  Creates a complete backup of the Kuzu database (.kuzu file) with:
+  Creates a complete backup of the graph database (.kuzu file) with:
   - **Format**: Full database backup only (complete .kuzu file)
   - **Compression**: Always enabled for optimal storage
   - **Encryption**: Optional AES-256 encryption for security
@@ -195,6 +195,23 @@ def sync(
   - **Download Support**: Unencrypted backups can be downloaded
   - **Restore Support**: Future support for encrypted backup restoration
 
+  **Operation State Machine:**
+  ```
+  pending → processing → completed
+                      ↘ failed
+  ```
+  - **pending**: Backup queued, waiting to start
+  - **processing**: Actively backing up database
+  - **completed**: Backup successfully created and stored
+  - **failed**: Backup failed (check error message)
+
+  **Expected Durations:**
+  Operation times vary by database size:
+  - **Small** (<1GB): 30 seconds - 2 minutes
+  - **Medium** (1-10GB): 2-10 minutes
+  - **Large** (10-100GB): 10-30 minutes
+  - **Very Large** (>100GB): 30+ minutes
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -202,6 +219,7 @@ def sync(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Backup progress:', data.progress_percent + '%');
+    console.log('Status:', data.status); // pending, processing, completed, failed
   });
   ```
 
@@ -225,9 +243,7 @@ def sync(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (BackupCreateRequest): Request model for creating a backup.
 
   Raises:
@@ -242,8 +258,6 @@ def sync(
     graph_id=graph_id,
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -252,14 +266,12 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: BackupCreateRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Create Backup
 
    Create a backup of the graph database.
 
-  Creates a complete backup of the Kuzu database (.kuzu file) with:
+  Creates a complete backup of the graph database (.kuzu file) with:
   - **Format**: Full database backup only (complete .kuzu file)
   - **Compression**: Always enabled for optimal storage
   - **Encryption**: Optional AES-256 encryption for security
@@ -271,6 +283,23 @@ async def asyncio_detailed(
   - **Download Support**: Unencrypted backups can be downloaded
   - **Restore Support**: Future support for encrypted backup restoration
 
+  **Operation State Machine:**
+  ```
+  pending → processing → completed
+                      ↘ failed
+  ```
+  - **pending**: Backup queued, waiting to start
+  - **processing**: Actively backing up database
+  - **completed**: Backup successfully created and stored
+  - **failed**: Backup failed (check error message)
+
+  **Expected Durations:**
+  Operation times vary by database size:
+  - **Small** (<1GB): 30 seconds - 2 minutes
+  - **Medium** (1-10GB): 2-10 minutes
+  - **Large** (10-100GB): 10-30 minutes
+  - **Very Large** (>100GB): 30+ minutes
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -278,6 +307,7 @@ async def asyncio_detailed(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Backup progress:', data.progress_percent + '%');
+    console.log('Status:', data.status); // pending, processing, completed, failed
   });
   ```
 
@@ -301,9 +331,7 @@ async def asyncio_detailed(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (BackupCreateRequest): Request model for creating a backup.
 
   Raises:
@@ -317,8 +345,6 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -331,14 +357,12 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: BackupCreateRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Create Backup
 
    Create a backup of the graph database.
 
-  Creates a complete backup of the Kuzu database (.kuzu file) with:
+  Creates a complete backup of the graph database (.kuzu file) with:
   - **Format**: Full database backup only (complete .kuzu file)
   - **Compression**: Always enabled for optimal storage
   - **Encryption**: Optional AES-256 encryption for security
@@ -350,6 +374,23 @@ async def asyncio(
   - **Download Support**: Unencrypted backups can be downloaded
   - **Restore Support**: Future support for encrypted backup restoration
 
+  **Operation State Machine:**
+  ```
+  pending → processing → completed
+                      ↘ failed
+  ```
+  - **pending**: Backup queued, waiting to start
+  - **processing**: Actively backing up database
+  - **completed**: Backup successfully created and stored
+  - **failed**: Backup failed (check error message)
+
+  **Expected Durations:**
+  Operation times vary by database size:
+  - **Small** (<1GB): 30 seconds - 2 minutes
+  - **Medium** (1-10GB): 2-10 minutes
+  - **Large** (10-100GB): 10-30 minutes
+  - **Very Large** (>100GB): 30+ minutes
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -357,6 +398,7 @@ async def asyncio(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Backup progress:', data.progress_percent + '%');
+    console.log('Status:', data.status); // pending, processing, completed, failed
   });
   ```
 
@@ -380,9 +422,7 @@ async def asyncio(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (BackupCreateRequest): Request model for creating a backup.
 
   Raises:
@@ -398,7 +438,5 @@ async def asyncio(
       graph_id=graph_id,
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
