@@ -8,35 +8,20 @@ from ...client import AuthenticatedClient, Client
 from ...models.backup_restore_request import BackupRestoreRequest
 from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
+  backup_id: str,
   *,
   body: BackupRestoreRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
-    "url": f"/v1/graphs/{graph_id}/backups/restore",
-    "params": params,
+    "url": f"/v1/graphs/{graph_id}/backups/{backup_id}/restore",
   }
 
   _kwargs["json"] = body.to_dict()
@@ -53,26 +38,32 @@ def _parse_response(
   if response.status_code == 202:
     response_202 = response.json()
     return response_202
+
   if response.status_code == 400:
     response_400 = ErrorResponse.from_dict(response.json())
 
     return response_400
+
   if response.status_code == 403:
     response_403 = ErrorResponse.from_dict(response.json())
 
     return response_403
+
   if response.status_code == 404:
     response_404 = ErrorResponse.from_dict(response.json())
 
     return response_404
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -92,17 +83,16 @@ def _build_response(
 
 def sync_detailed(
   graph_id: str,
+  backup_id: str,
   *,
   client: AuthenticatedClient,
   body: BackupRestoreRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Restore Encrypted Backup
 
    Restore a graph database from an encrypted backup.
 
-  Restores a complete Kuzu database from an encrypted backup:
+  Restores a complete graph database from an encrypted backup:
   - **Format**: Only full_dump backups can be restored
   - **Encryption**: Only encrypted backups can be restored (security requirement)
   - **System Backup**: Creates automatic backup of existing database before restore
@@ -114,6 +104,28 @@ def sync_detailed(
   - **Data Integrity**: Verification ensures successful restore
   - **Security**: Only encrypted backups to prevent data tampering
 
+  **Operation State Machine:**
+  ```
+  pending → backing_up_current → downloading → restoring → verifying → completed
+                                                                     ↘ failed
+  ```
+  - **pending**: Restore queued, waiting to start
+  - **backing_up_current**: Creating safety backup of existing database
+  - **downloading**: Downloading backup from storage
+  - **restoring**: Replacing database with backup contents
+  - **verifying**: Verifying database integrity (if enabled)
+  - **completed**: Restore successful, database operational
+  - **failed**: Restore failed (rollback may be available)
+
+  **Expected Durations:**
+  Operation times vary by database size (includes backup + restore):
+  - **Small** (<1GB): 1-3 minutes
+  - **Medium** (1-10GB): 5-15 minutes
+  - **Large** (10-100GB): 20-45 minutes
+  - **Very Large** (>100GB): 45+ minutes
+
+  Note: Restore operations take longer than backups due to safety backup step.
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -121,6 +133,7 @@ def sync_detailed(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Restore progress:', data.message);
+    console.log('Status:', data.status); // Shows current state
   });
   ```
 
@@ -144,9 +157,8 @@ def sync_detailed(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
+      backup_id (str): Backup identifier
       body (BackupRestoreRequest): Request model for restoring from a backup.
 
   Raises:
@@ -159,9 +171,8 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
+    backup_id=backup_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -173,17 +184,16 @@ def sync_detailed(
 
 def sync(
   graph_id: str,
+  backup_id: str,
   *,
   client: AuthenticatedClient,
   body: BackupRestoreRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Restore Encrypted Backup
 
    Restore a graph database from an encrypted backup.
 
-  Restores a complete Kuzu database from an encrypted backup:
+  Restores a complete graph database from an encrypted backup:
   - **Format**: Only full_dump backups can be restored
   - **Encryption**: Only encrypted backups can be restored (security requirement)
   - **System Backup**: Creates automatic backup of existing database before restore
@@ -195,6 +205,28 @@ def sync(
   - **Data Integrity**: Verification ensures successful restore
   - **Security**: Only encrypted backups to prevent data tampering
 
+  **Operation State Machine:**
+  ```
+  pending → backing_up_current → downloading → restoring → verifying → completed
+                                                                     ↘ failed
+  ```
+  - **pending**: Restore queued, waiting to start
+  - **backing_up_current**: Creating safety backup of existing database
+  - **downloading**: Downloading backup from storage
+  - **restoring**: Replacing database with backup contents
+  - **verifying**: Verifying database integrity (if enabled)
+  - **completed**: Restore successful, database operational
+  - **failed**: Restore failed (rollback may be available)
+
+  **Expected Durations:**
+  Operation times vary by database size (includes backup + restore):
+  - **Small** (<1GB): 1-3 minutes
+  - **Medium** (1-10GB): 5-15 minutes
+  - **Large** (10-100GB): 20-45 minutes
+  - **Very Large** (>100GB): 45+ minutes
+
+  Note: Restore operations take longer than backups due to safety backup step.
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -202,6 +234,7 @@ def sync(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Restore progress:', data.message);
+    console.log('Status:', data.status); // Shows current state
   });
   ```
 
@@ -225,9 +258,8 @@ def sync(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
+      backup_id (str): Backup identifier
       body (BackupRestoreRequest): Request model for restoring from a backup.
 
   Raises:
@@ -240,26 +272,24 @@ def sync(
 
   return sync_detailed(
     graph_id=graph_id,
+    backup_id=backup_id,
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
 async def asyncio_detailed(
   graph_id: str,
+  backup_id: str,
   *,
   client: AuthenticatedClient,
   body: BackupRestoreRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Restore Encrypted Backup
 
    Restore a graph database from an encrypted backup.
 
-  Restores a complete Kuzu database from an encrypted backup:
+  Restores a complete graph database from an encrypted backup:
   - **Format**: Only full_dump backups can be restored
   - **Encryption**: Only encrypted backups can be restored (security requirement)
   - **System Backup**: Creates automatic backup of existing database before restore
@@ -271,6 +301,28 @@ async def asyncio_detailed(
   - **Data Integrity**: Verification ensures successful restore
   - **Security**: Only encrypted backups to prevent data tampering
 
+  **Operation State Machine:**
+  ```
+  pending → backing_up_current → downloading → restoring → verifying → completed
+                                                                     ↘ failed
+  ```
+  - **pending**: Restore queued, waiting to start
+  - **backing_up_current**: Creating safety backup of existing database
+  - **downloading**: Downloading backup from storage
+  - **restoring**: Replacing database with backup contents
+  - **verifying**: Verifying database integrity (if enabled)
+  - **completed**: Restore successful, database operational
+  - **failed**: Restore failed (rollback may be available)
+
+  **Expected Durations:**
+  Operation times vary by database size (includes backup + restore):
+  - **Small** (<1GB): 1-3 minutes
+  - **Medium** (1-10GB): 5-15 minutes
+  - **Large** (10-100GB): 20-45 minutes
+  - **Very Large** (>100GB): 45+ minutes
+
+  Note: Restore operations take longer than backups due to safety backup step.
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -278,6 +330,7 @@ async def asyncio_detailed(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Restore progress:', data.message);
+    console.log('Status:', data.status); // Shows current state
   });
   ```
 
@@ -301,9 +354,8 @@ async def asyncio_detailed(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
+      backup_id (str): Backup identifier
       body (BackupRestoreRequest): Request model for restoring from a backup.
 
   Raises:
@@ -316,9 +368,8 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
+    backup_id=backup_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -328,17 +379,16 @@ async def asyncio_detailed(
 
 async def asyncio(
   graph_id: str,
+  backup_id: str,
   *,
   client: AuthenticatedClient,
   body: BackupRestoreRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """Restore Encrypted Backup
 
    Restore a graph database from an encrypted backup.
 
-  Restores a complete Kuzu database from an encrypted backup:
+  Restores a complete graph database from an encrypted backup:
   - **Format**: Only full_dump backups can be restored
   - **Encryption**: Only encrypted backups can be restored (security requirement)
   - **System Backup**: Creates automatic backup of existing database before restore
@@ -350,6 +400,28 @@ async def asyncio(
   - **Data Integrity**: Verification ensures successful restore
   - **Security**: Only encrypted backups to prevent data tampering
 
+  **Operation State Machine:**
+  ```
+  pending → backing_up_current → downloading → restoring → verifying → completed
+                                                                     ↘ failed
+  ```
+  - **pending**: Restore queued, waiting to start
+  - **backing_up_current**: Creating safety backup of existing database
+  - **downloading**: Downloading backup from storage
+  - **restoring**: Replacing database with backup contents
+  - **verifying**: Verifying database integrity (if enabled)
+  - **completed**: Restore successful, database operational
+  - **failed**: Restore failed (rollback may be available)
+
+  **Expected Durations:**
+  Operation times vary by database size (includes backup + restore):
+  - **Small** (<1GB): 1-3 minutes
+  - **Medium** (1-10GB): 5-15 minutes
+  - **Large** (10-100GB): 20-45 minutes
+  - **Very Large** (>100GB): 45+ minutes
+
+  Note: Restore operations take longer than backups due to safety backup step.
+
   **Progress Monitoring:**
   Use the returned operation_id to connect to the SSE stream:
   ```javascript
@@ -357,6 +429,7 @@ async def asyncio(
   eventSource.addEventListener('operation_progress', (event) => {
     const data = JSON.parse(event.data);
     console.log('Restore progress:', data.message);
+    console.log('Status:', data.status); // Shows current state
   });
   ```
 
@@ -380,9 +453,8 @@ async def asyncio(
   Returns operation details for SSE monitoring.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
+      backup_id (str): Backup identifier
       body (BackupRestoreRequest): Request model for restoring from a backup.
 
   Raises:
@@ -396,9 +468,8 @@ async def asyncio(
   return (
     await asyncio_detailed(
       graph_id=graph_id,
+      backup_id=backup_id,
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
