@@ -8,38 +8,18 @@ from ...client import AuthenticatedClient, Client
 from ...models.connection_response import ConnectionResponse
 from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
   connection_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/graphs/{graph_id}/connections/{connection_id}",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -50,22 +30,27 @@ def _parse_response(
     response_200 = ConnectionResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 403:
     response_403 = ErrorResponse.from_dict(response.json())
 
     return response_403
+
   if response.status_code == 404:
     response_404 = ErrorResponse.from_dict(response.json())
 
     return response_404
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -88,8 +73,6 @@ def sync_detailed(
   connection_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Get Connection
 
@@ -105,10 +88,8 @@ def sync_detailed(
   No credits are consumed for viewing connection details.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       connection_id (str): Unique connection identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -121,8 +102,6 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     connection_id=connection_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -137,8 +116,6 @@ def sync(
   connection_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Get Connection
 
@@ -154,10 +131,8 @@ def sync(
   No credits are consumed for viewing connection details.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       connection_id (str): Unique connection identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -171,8 +146,6 @@ def sync(
     graph_id=graph_id,
     connection_id=connection_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -181,8 +154,6 @@ async def asyncio_detailed(
   connection_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Get Connection
 
@@ -198,10 +169,8 @@ async def asyncio_detailed(
   No credits are consumed for viewing connection details.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       connection_id (str): Unique connection identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -214,8 +183,6 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     connection_id=connection_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -228,8 +195,6 @@ async def asyncio(
   connection_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ConnectionResponse, ErrorResponse, HTTPValidationError]]:
   """Get Connection
 
@@ -245,10 +210,8 @@ async def asyncio(
   No credits are consumed for viewing connection details.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       connection_id (str): Unique connection identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -263,7 +226,5 @@ async def asyncio(
       graph_id=graph_id,
       connection_id=connection_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
