@@ -8,7 +8,7 @@ from ...client import AuthenticatedClient, Client
 from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
 from ...models.o_auth_callback_request import OAuthCallbackRequest
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
@@ -16,28 +16,12 @@ def _get_kwargs(
   provider: str,
   *,
   body: OAuthCallbackRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
     "url": f"/v1/graphs/{graph_id}/connections/oauth/callback/{provider}",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -54,26 +38,32 @@ def _parse_response(
   if response.status_code == 200:
     response_200 = response.json()
     return response_200
+
   if response.status_code == 400:
     response_400 = ErrorResponse.from_dict(response.json())
 
     return response_400
+
   if response.status_code == 403:
     response_403 = ErrorResponse.from_dict(response.json())
 
     return response_403
+
   if response.status_code == 404:
     response_404 = ErrorResponse.from_dict(response.json())
 
     return response_404
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -97,8 +87,6 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: OAuthCallbackRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """OAuth Callback
 
@@ -123,10 +111,8 @@ def sync_detailed(
   No credits are consumed for OAuth callbacks.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       provider (str): OAuth provider name
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (OAuthCallbackRequest): OAuth callback parameters.
 
   Raises:
@@ -141,8 +127,6 @@ def sync_detailed(
     graph_id=graph_id,
     provider=provider,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -158,8 +142,6 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: OAuthCallbackRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """OAuth Callback
 
@@ -184,10 +166,8 @@ def sync(
   No credits are consumed for OAuth callbacks.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       provider (str): OAuth provider name
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (OAuthCallbackRequest): OAuth callback parameters.
 
   Raises:
@@ -203,8 +183,6 @@ def sync(
     provider=provider,
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -214,8 +192,6 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: OAuthCallbackRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, ErrorResponse, HTTPValidationError]]:
   """OAuth Callback
 
@@ -240,10 +216,8 @@ async def asyncio_detailed(
   No credits are consumed for OAuth callbacks.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       provider (str): OAuth provider name
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (OAuthCallbackRequest): OAuth callback parameters.
 
   Raises:
@@ -258,8 +232,6 @@ async def asyncio_detailed(
     graph_id=graph_id,
     provider=provider,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -273,8 +245,6 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: OAuthCallbackRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, ErrorResponse, HTTPValidationError]]:
   """OAuth Callback
 
@@ -299,10 +269,8 @@ async def asyncio(
   No credits are consumed for OAuth callbacks.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       provider (str): OAuth provider name
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (OAuthCallbackRequest): OAuth callback parameters.
 
   Raises:
@@ -319,7 +287,5 @@ async def asyncio(
       provider=provider,
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
