@@ -5,64 +5,47 @@ import httpx
 
 from ... import errors
 from ...client import AuthenticatedClient, Client
-from ...models.get_graph_limits_response_getgraphlimits import (
-  GetGraphLimitsResponseGetgraphlimits,
-)
+from ...models.graph_limits_response import GraphLimitsResponse
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/graphs/{graph_id}/limits",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
 def _parse_response(
   *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]:
+) -> Optional[Union[Any, GraphLimitsResponse, HTTPValidationError]]:
   if response.status_code == 200:
-    response_200 = GetGraphLimitsResponseGetgraphlimits.from_dict(response.json())
+    response_200 = GraphLimitsResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 403:
     response_403 = cast(Any, None)
     return response_403
+
   if response.status_code == 404:
     response_404 = cast(Any, None)
     return response_404
-  if response.status_code == 500:
-    response_500 = cast(Any, None)
-    return response_500
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = cast(Any, None)
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -71,7 +54,7 @@ def _parse_response(
 
 def _build_response(
   *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]:
+) -> Response[Union[Any, GraphLimitsResponse, HTTPValidationError]]:
   return Response(
     status_code=HTTPStatus(response.status_code),
     content=response.content,
@@ -84,9 +67,7 @@ def sync_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Response[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]:
+) -> Response[Union[Any, GraphLimitsResponse, HTTPValidationError]]:
   """Get Graph Operational Limits
 
    Get comprehensive operational limits for the graph database.
@@ -104,22 +85,18 @@ def sync_detailed(
   **Note**: Limits vary based on subscription tier (Standard, Enterprise, Premium).
 
   Args:
-      graph_id (str): Graph database identifier (user graph or shared repository)
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Response[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]
+      Response[Union[Any, GraphLimitsResponse, HTTPValidationError]]
   """
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -133,9 +110,7 @@ def sync(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Optional[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]:
+) -> Optional[Union[Any, GraphLimitsResponse, HTTPValidationError]]:
   """Get Graph Operational Limits
 
    Get comprehensive operational limits for the graph database.
@@ -153,23 +128,19 @@ def sync(
   **Note**: Limits vary based on subscription tier (Standard, Enterprise, Premium).
 
   Args:
-      graph_id (str): Graph database identifier (user graph or shared repository)
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]
+      Union[Any, GraphLimitsResponse, HTTPValidationError]
   """
 
   return sync_detailed(
     graph_id=graph_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -177,9 +148,7 @@ async def asyncio_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Response[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]:
+) -> Response[Union[Any, GraphLimitsResponse, HTTPValidationError]]:
   """Get Graph Operational Limits
 
    Get comprehensive operational limits for the graph database.
@@ -197,22 +166,18 @@ async def asyncio_detailed(
   **Note**: Limits vary based on subscription tier (Standard, Enterprise, Premium).
 
   Args:
-      graph_id (str): Graph database identifier (user graph or shared repository)
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Response[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]
+      Response[Union[Any, GraphLimitsResponse, HTTPValidationError]]
   """
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -224,9 +189,7 @@ async def asyncio(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Optional[Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]]:
+) -> Optional[Union[Any, GraphLimitsResponse, HTTPValidationError]]:
   """Get Graph Operational Limits
 
    Get comprehensive operational limits for the graph database.
@@ -244,23 +207,19 @@ async def asyncio(
   **Note**: Limits vary based on subscription tier (Standard, Enterprise, Premium).
 
   Args:
-      graph_id (str): Graph database identifier (user graph or shared repository)
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Union[Any, GetGraphLimitsResponseGetgraphlimits, HTTPValidationError]
+      Union[Any, GraphLimitsResponse, HTTPValidationError]
   """
 
   return (
     await asyncio_detailed(
       graph_id=graph_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
