@@ -8,37 +8,17 @@ from ...client import AuthenticatedClient, Client
 from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
 from ...models.mcp_tools_response import MCPToolsResponse
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/graphs/{graph_id}/mcp/tools",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -49,18 +29,22 @@ def _parse_response(
     response_200 = MCPToolsResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 403:
     response_403 = ErrorResponse.from_dict(response.json())
 
     return response_403
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -82,8 +66,6 @@ def sync_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, MCPToolsResponse]]:
   """List MCP Tools
 
@@ -99,14 +81,11 @@ def sync_detailed(
   - User permissions and subscription tier
   - Backend capabilities (Kuzu, Neo4j, etc.)
 
-  Credit consumption:
-  - Listing tools is FREE to encourage exploration
-  - Tool execution costs vary by operation complexity
+  **Note:**
+  MCP tool listing is included - no credit consumption required.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -118,8 +97,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -133,8 +110,6 @@ def sync(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, MCPToolsResponse]]:
   """List MCP Tools
 
@@ -150,14 +125,11 @@ def sync(
   - User permissions and subscription tier
   - Backend capabilities (Kuzu, Neo4j, etc.)
 
-  Credit consumption:
-  - Listing tools is FREE to encourage exploration
-  - Tool execution costs vary by operation complexity
+  **Note:**
+  MCP tool listing is included - no credit consumption required.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -170,8 +142,6 @@ def sync(
   return sync_detailed(
     graph_id=graph_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -179,8 +149,6 @@ async def asyncio_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, MCPToolsResponse]]:
   """List MCP Tools
 
@@ -196,14 +164,11 @@ async def asyncio_detailed(
   - User permissions and subscription tier
   - Backend capabilities (Kuzu, Neo4j, etc.)
 
-  Credit consumption:
-  - Listing tools is FREE to encourage exploration
-  - Tool execution costs vary by operation complexity
+  **Note:**
+  MCP tool listing is included - no credit consumption required.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -215,8 +180,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -228,8 +191,6 @@ async def asyncio(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, MCPToolsResponse]]:
   """List MCP Tools
 
@@ -245,14 +206,11 @@ async def asyncio(
   - User permissions and subscription tier
   - Backend capabilities (Kuzu, Neo4j, etc.)
 
-  Credit consumption:
-  - Listing tools is FREE to encourage exploration
-  - Tool execution costs vary by operation complexity
+  **Note:**
+  MCP tool listing is included - no credit consumption required.
 
   Args:
-      graph_id (str): Graph database identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -266,7 +224,5 @@ async def asyncio(
     await asyncio_detailed(
       graph_id=graph_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
