@@ -9,37 +9,17 @@ from ...models.cancel_operation_response_canceloperation import (
   CancelOperationResponseCanceloperation,
 )
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   operation_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "delete",
     "url": f"/v1/operations/{operation_id}",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -50,22 +30,28 @@ def _parse_response(
     response_200 = CancelOperationResponseCanceloperation.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 403:
     response_403 = cast(Any, None)
     return response_403
+
   if response.status_code == 404:
     response_404 = cast(Any, None)
     return response_404
+
   if response.status_code == 409:
     response_409 = cast(Any, None)
     return response_409
-  if response.status_code == 500:
-    response_500 = cast(Any, None)
-    return response_500
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = cast(Any, None)
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -87,8 +73,6 @@ def sync_detailed(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, CancelOperationResponseCanceloperation, HTTPValidationError]]:
   """Cancel Operation
 
@@ -104,8 +88,6 @@ def sync_detailed(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -117,8 +99,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     operation_id=operation_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -132,8 +112,6 @@ def sync(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, CancelOperationResponseCanceloperation, HTTPValidationError]]:
   """Cancel Operation
 
@@ -149,8 +127,6 @@ def sync(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -163,8 +139,6 @@ def sync(
   return sync_detailed(
     operation_id=operation_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -172,8 +146,6 @@ async def asyncio_detailed(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, CancelOperationResponseCanceloperation, HTTPValidationError]]:
   """Cancel Operation
 
@@ -189,8 +161,6 @@ async def asyncio_detailed(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -202,8 +172,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     operation_id=operation_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -215,8 +183,6 @@ async def asyncio(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, CancelOperationResponseCanceloperation, HTTPValidationError]]:
   """Cancel Operation
 
@@ -232,8 +198,6 @@ async def asyncio(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -247,7 +211,5 @@ async def asyncio(
     await asyncio_detailed(
       operation_id=operation_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
