@@ -9,37 +9,17 @@ from ...models.get_operation_status_response_getoperationstatus import (
   GetOperationStatusResponseGetoperationstatus,
 )
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   operation_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/operations/{operation_id}/status",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -54,19 +34,24 @@ def _parse_response(
     )
 
     return response_200
+
   if response.status_code == 403:
     response_403 = cast(Any, None)
     return response_403
+
   if response.status_code == 404:
     response_404 = cast(Any, None)
     return response_404
-  if response.status_code == 500:
-    response_500 = cast(Any, None)
-    return response_500
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = cast(Any, None)
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -90,8 +75,6 @@ def sync_detailed(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[
   Union[Any, GetOperationStatusResponseGetoperationstatus, HTTPValidationError]
 ]:
@@ -113,8 +96,6 @@ def sync_detailed(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -126,8 +107,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     operation_id=operation_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -141,8 +120,6 @@ def sync(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[
   Union[Any, GetOperationStatusResponseGetoperationstatus, HTTPValidationError]
 ]:
@@ -164,8 +141,6 @@ def sync(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -178,8 +153,6 @@ def sync(
   return sync_detailed(
     operation_id=operation_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -187,8 +160,6 @@ async def asyncio_detailed(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[
   Union[Any, GetOperationStatusResponseGetoperationstatus, HTTPValidationError]
 ]:
@@ -210,8 +181,6 @@ async def asyncio_detailed(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -223,8 +192,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     operation_id=operation_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -236,8 +203,6 @@ async def asyncio(
   operation_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[
   Union[Any, GetOperationStatusResponseGetoperationstatus, HTTPValidationError]
 ]:
@@ -259,8 +224,6 @@ async def asyncio(
 
   Args:
       operation_id (str): Operation identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -274,7 +237,5 @@ async def asyncio(
     await asyncio_detailed(
       operation_id=operation_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
