@@ -6,6 +6,7 @@ import httpx
 from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.cypher_query_request import CypherQueryRequest
+from ...models.execute_cypher_query_response_200 import ExecuteCypherQueryResponse200
 from ...models.http_validation_error import HTTPValidationError
 from ...models.response_mode import ResponseMode
 from ...types import UNSET, Response, Unset
@@ -16,14 +17,10 @@ def _get_kwargs(
   *,
   body: CypherQueryRequest,
   mode: Union[None, ResponseMode, Unset] = UNSET,
-  chunk_size: Union[Unset, int] = 1000,
+  chunk_size: Union[None, Unset, int] = UNSET,
   test_mode: Union[Unset, bool] = False,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
 
   params: dict[str, Any] = {}
 
@@ -36,17 +33,15 @@ def _get_kwargs(
     json_mode = mode
   params["mode"] = json_mode
 
-  params["chunk_size"] = chunk_size
+  json_chunk_size: Union[None, Unset, int]
+  if isinstance(chunk_size, Unset):
+    json_chunk_size = UNSET
+  else:
+    json_chunk_size = chunk_size
+  params["chunk_size"] = json_chunk_size
 
   params["test_mode"] = test_mode
 
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
   params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
@@ -65,35 +60,51 @@ def _get_kwargs(
 
 def _parse_response(
   *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Optional[Union[Any, HTTPValidationError]]:
+) -> Optional[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]:
   if response.status_code == 200:
-    response_200 = response.json()
+    content_type = response.headers.get("content-type", "")
+    if (
+      "application/x-ndjson" in content_type
+      or response.headers.get("x-stream-format") == "ndjson"
+    ):
+      return None
+    response_200 = ExecuteCypherQueryResponse200.from_dict(response.json())
+
     return response_200
+
   if response.status_code == 202:
     response_202 = cast(Any, None)
     return response_202
+
   if response.status_code == 400:
     response_400 = cast(Any, None)
     return response_400
+
   if response.status_code == 403:
     response_403 = cast(Any, None)
     return response_403
+
   if response.status_code == 408:
     response_408 = cast(Any, None)
     return response_408
-  if response.status_code == 429:
-    response_429 = cast(Any, None)
-    return response_429
-  if response.status_code == 500:
-    response_500 = cast(Any, None)
-    return response_500
-  if response.status_code == 503:
-    response_503 = cast(Any, None)
-    return response_503
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 429:
+    response_429 = cast(Any, None)
+    return response_429
+
+  if response.status_code == 500:
+    response_500 = cast(Any, None)
+    return response_500
+
+  if response.status_code == 503:
+    response_503 = cast(Any, None)
+    return response_503
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -102,7 +113,7 @@ def _parse_response(
 
 def _build_response(
   *, client: Union[AuthenticatedClient, Client], response: httpx.Response
-) -> Response[Union[Any, HTTPValidationError]]:
+) -> Response[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]:
   return Response(
     status_code=HTTPStatus(response.status_code),
     content=response.content,
@@ -117,14 +128,28 @@ def sync_detailed(
   client: AuthenticatedClient,
   body: CypherQueryRequest,
   mode: Union[None, ResponseMode, Unset] = UNSET,
-  chunk_size: Union[Unset, int] = 1000,
+  chunk_size: Union[None, Unset, int] = UNSET,
   test_mode: Union[Unset, bool] = False,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Response[Union[Any, HTTPValidationError]]:
-  """Execute Cypher Query
+) -> Response[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]:
+  r"""Execute Cypher Query (Read-Only)
 
-   Execute a Cypher query with intelligent response optimization.
+   Execute a read-only Cypher query with intelligent response optimization.
+
+  **IMPORTANT: This endpoint is READ-ONLY.** Write operations (CREATE, MERGE, SET, DELETE) are not
+  allowed.
+  To load data into your graph, use the staging pipeline:
+  1. Create file upload: `POST /v1/graphs/{graph_id}/tables/{table_name}/files`
+  2. Ingest to graph: `POST /v1/graphs/{graph_id}/tables/ingest`
+
+  **Security Best Practice - Use Parameterized Queries:**
+  ALWAYS use query parameters instead of string interpolation to prevent injection attacks:
+  - ✅ SAFE: `MATCH (n:Entity {type: $entity_type}) RETURN n` with `parameters: {\"entity_type\":
+  \"Company\"}`
+  - ❌ UNSAFE: `MATCH (n:Entity {type: \"Company\"}) RETURN n` with user input concatenated into query
+  string
+
+  Query parameters provide automatic escaping and type safety. All examples in this API use
+  parameterized queries.
 
   This endpoint automatically selects the best execution strategy based on:
   - Query characteristics (size, complexity)
@@ -169,16 +194,14 @@ def sync_detailed(
   - Clients should implement exponential backoff
 
   **Note:**
-  Query operations are FREE - no credit consumption required.
+  Query operations are included - no credit consumption required.
   Queue position is based on subscription tier for priority.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       mode (Union[None, ResponseMode, Unset]): Response mode override
-      chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
+      chunk_size (Union[None, Unset, int]): Rows per chunk for streaming
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -186,7 +209,7 @@ def sync_detailed(
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Response[Union[Any, HTTPValidationError]]
+      Response[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]
   """
 
   kwargs = _get_kwargs(
@@ -195,8 +218,6 @@ def sync_detailed(
     mode=mode,
     chunk_size=chunk_size,
     test_mode=test_mode,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -212,14 +233,28 @@ def sync(
   client: AuthenticatedClient,
   body: CypherQueryRequest,
   mode: Union[None, ResponseMode, Unset] = UNSET,
-  chunk_size: Union[Unset, int] = 1000,
+  chunk_size: Union[None, Unset, int] = UNSET,
   test_mode: Union[Unset, bool] = False,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Optional[Union[Any, HTTPValidationError]]:
-  """Execute Cypher Query
+) -> Optional[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]:
+  r"""Execute Cypher Query (Read-Only)
 
-   Execute a Cypher query with intelligent response optimization.
+   Execute a read-only Cypher query with intelligent response optimization.
+
+  **IMPORTANT: This endpoint is READ-ONLY.** Write operations (CREATE, MERGE, SET, DELETE) are not
+  allowed.
+  To load data into your graph, use the staging pipeline:
+  1. Create file upload: `POST /v1/graphs/{graph_id}/tables/{table_name}/files`
+  2. Ingest to graph: `POST /v1/graphs/{graph_id}/tables/ingest`
+
+  **Security Best Practice - Use Parameterized Queries:**
+  ALWAYS use query parameters instead of string interpolation to prevent injection attacks:
+  - ✅ SAFE: `MATCH (n:Entity {type: $entity_type}) RETURN n` with `parameters: {\"entity_type\":
+  \"Company\"}`
+  - ❌ UNSAFE: `MATCH (n:Entity {type: \"Company\"}) RETURN n` with user input concatenated into query
+  string
+
+  Query parameters provide automatic escaping and type safety. All examples in this API use
+  parameterized queries.
 
   This endpoint automatically selects the best execution strategy based on:
   - Query characteristics (size, complexity)
@@ -264,16 +299,14 @@ def sync(
   - Clients should implement exponential backoff
 
   **Note:**
-  Query operations are FREE - no credit consumption required.
+  Query operations are included - no credit consumption required.
   Queue position is based on subscription tier for priority.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       mode (Union[None, ResponseMode, Unset]): Response mode override
-      chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
+      chunk_size (Union[None, Unset, int]): Rows per chunk for streaming
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -281,7 +314,7 @@ def sync(
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Union[Any, HTTPValidationError]
+      Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]
   """
 
   return sync_detailed(
@@ -291,8 +324,6 @@ def sync(
     mode=mode,
     chunk_size=chunk_size,
     test_mode=test_mode,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -302,14 +333,28 @@ async def asyncio_detailed(
   client: AuthenticatedClient,
   body: CypherQueryRequest,
   mode: Union[None, ResponseMode, Unset] = UNSET,
-  chunk_size: Union[Unset, int] = 1000,
+  chunk_size: Union[None, Unset, int] = UNSET,
   test_mode: Union[Unset, bool] = False,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Response[Union[Any, HTTPValidationError]]:
-  """Execute Cypher Query
+) -> Response[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]:
+  r"""Execute Cypher Query (Read-Only)
 
-   Execute a Cypher query with intelligent response optimization.
+   Execute a read-only Cypher query with intelligent response optimization.
+
+  **IMPORTANT: This endpoint is READ-ONLY.** Write operations (CREATE, MERGE, SET, DELETE) are not
+  allowed.
+  To load data into your graph, use the staging pipeline:
+  1. Create file upload: `POST /v1/graphs/{graph_id}/tables/{table_name}/files`
+  2. Ingest to graph: `POST /v1/graphs/{graph_id}/tables/ingest`
+
+  **Security Best Practice - Use Parameterized Queries:**
+  ALWAYS use query parameters instead of string interpolation to prevent injection attacks:
+  - ✅ SAFE: `MATCH (n:Entity {type: $entity_type}) RETURN n` with `parameters: {\"entity_type\":
+  \"Company\"}`
+  - ❌ UNSAFE: `MATCH (n:Entity {type: \"Company\"}) RETURN n` with user input concatenated into query
+  string
+
+  Query parameters provide automatic escaping and type safety. All examples in this API use
+  parameterized queries.
 
   This endpoint automatically selects the best execution strategy based on:
   - Query characteristics (size, complexity)
@@ -354,16 +399,14 @@ async def asyncio_detailed(
   - Clients should implement exponential backoff
 
   **Note:**
-  Query operations are FREE - no credit consumption required.
+  Query operations are included - no credit consumption required.
   Queue position is based on subscription tier for priority.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       mode (Union[None, ResponseMode, Unset]): Response mode override
-      chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
+      chunk_size (Union[None, Unset, int]): Rows per chunk for streaming
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -371,7 +414,7 @@ async def asyncio_detailed(
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Response[Union[Any, HTTPValidationError]]
+      Response[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]
   """
 
   kwargs = _get_kwargs(
@@ -380,8 +423,6 @@ async def asyncio_detailed(
     mode=mode,
     chunk_size=chunk_size,
     test_mode=test_mode,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -395,14 +436,28 @@ async def asyncio(
   client: AuthenticatedClient,
   body: CypherQueryRequest,
   mode: Union[None, ResponseMode, Unset] = UNSET,
-  chunk_size: Union[Unset, int] = 1000,
+  chunk_size: Union[None, Unset, int] = UNSET,
   test_mode: Union[Unset, bool] = False,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
-) -> Optional[Union[Any, HTTPValidationError]]:
-  """Execute Cypher Query
+) -> Optional[Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]]:
+  r"""Execute Cypher Query (Read-Only)
 
-   Execute a Cypher query with intelligent response optimization.
+   Execute a read-only Cypher query with intelligent response optimization.
+
+  **IMPORTANT: This endpoint is READ-ONLY.** Write operations (CREATE, MERGE, SET, DELETE) are not
+  allowed.
+  To load data into your graph, use the staging pipeline:
+  1. Create file upload: `POST /v1/graphs/{graph_id}/tables/{table_name}/files`
+  2. Ingest to graph: `POST /v1/graphs/{graph_id}/tables/ingest`
+
+  **Security Best Practice - Use Parameterized Queries:**
+  ALWAYS use query parameters instead of string interpolation to prevent injection attacks:
+  - ✅ SAFE: `MATCH (n:Entity {type: $entity_type}) RETURN n` with `parameters: {\"entity_type\":
+  \"Company\"}`
+  - ❌ UNSAFE: `MATCH (n:Entity {type: \"Company\"}) RETURN n` with user input concatenated into query
+  string
+
+  Query parameters provide automatic escaping and type safety. All examples in this API use
+  parameterized queries.
 
   This endpoint automatically selects the best execution strategy based on:
   - Query characteristics (size, complexity)
@@ -447,16 +502,14 @@ async def asyncio(
   - Clients should implement exponential backoff
 
   **Note:**
-  Query operations are FREE - no credit consumption required.
+  Query operations are included - no credit consumption required.
   Queue position is based on subscription tier for priority.
 
   Args:
-      graph_id (str): Graph database identifier
+      graph_id (str):
       mode (Union[None, ResponseMode, Unset]): Response mode override
-      chunk_size (Union[Unset, int]): Rows per chunk for streaming Default: 1000.
+      chunk_size (Union[None, Unset, int]): Rows per chunk for streaming
       test_mode (Union[Unset, bool]): Enable test mode for better debugging Default: False.
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CypherQueryRequest): Request model for Cypher query execution.
 
   Raises:
@@ -464,7 +517,7 @@ async def asyncio(
       httpx.TimeoutException: If the request takes longer than Client.timeout.
 
   Returns:
-      Union[Any, HTTPValidationError]
+      Union[Any, ExecuteCypherQueryResponse200, HTTPValidationError]
   """
 
   return (
@@ -475,7 +528,5 @@ async def asyncio(
       mode=mode,
       chunk_size=chunk_size,
       test_mode=test_mode,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
