@@ -8,35 +8,19 @@ from ...client import AuthenticatedClient, Client
 from ...models.create_subgraph_request import CreateSubgraphRequest
 from ...models.http_validation_error import HTTPValidationError
 from ...models.subgraph_response import SubgraphResponse
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
   *,
   body: CreateSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
     "url": f"/v1/graphs/{graph_id}/subgraphs",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -54,10 +38,12 @@ def _parse_response(
     response_201 = SubgraphResponse.from_dict(response.json())
 
     return response_201
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -80,8 +66,6 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: CreateSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
   """Create Subgraph
 
@@ -99,9 +83,7 @@ def sync_detailed(
   - Created subgraph details including its unique ID
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (CreateSubgraphRequest): Request model for creating a subgraph.
 
   Raises:
@@ -115,8 +97,6 @@ def sync_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -131,8 +111,6 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: CreateSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
   """Create Subgraph
 
@@ -150,9 +128,7 @@ def sync(
   - Created subgraph details including its unique ID
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (CreateSubgraphRequest): Request model for creating a subgraph.
 
   Raises:
@@ -167,8 +143,6 @@ def sync(
     graph_id=graph_id,
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -177,8 +151,6 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: CreateSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
   """Create Subgraph
 
@@ -196,9 +168,7 @@ async def asyncio_detailed(
   - Created subgraph details including its unique ID
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (CreateSubgraphRequest): Request model for creating a subgraph.
 
   Raises:
@@ -212,8 +182,6 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     graph_id=graph_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -226,8 +194,6 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: CreateSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
   """Create Subgraph
 
@@ -245,9 +211,7 @@ async def asyncio(
   - Created subgraph details including its unique ID
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
       body (CreateSubgraphRequest): Request model for creating a subgraph.
 
   Raises:
@@ -263,7 +227,5 @@ async def asyncio(
       graph_id=graph_id,
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
