@@ -8,7 +8,7 @@ from ...client import AuthenticatedClient, Client
 from ...models.delete_subgraph_request import DeleteSubgraphRequest
 from ...models.delete_subgraph_response import DeleteSubgraphResponse
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
@@ -16,28 +16,12 @@ def _get_kwargs(
   subgraph_id: str,
   *,
   body: DeleteSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "delete",
     "url": f"/v1/graphs/{graph_id}/subgraphs/{subgraph_id}",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -55,28 +39,36 @@ def _parse_response(
     response_200 = DeleteSubgraphResponse.from_dict(response.json())
 
     return response_200
-  if response.status_code == 401:
-    response_401 = cast(Any, None)
-    return response_401
-  if response.status_code == 403:
-    response_403 = cast(Any, None)
-    return response_403
-  if response.status_code == 404:
-    response_404 = cast(Any, None)
-    return response_404
+
   if response.status_code == 400:
     response_400 = cast(Any, None)
     return response_400
+
+  if response.status_code == 401:
+    response_401 = cast(Any, None)
+    return response_401
+
+  if response.status_code == 403:
+    response_403 = cast(Any, None)
+    return response_403
+
+  if response.status_code == 404:
+    response_404 = cast(Any, None)
+    return response_404
+
   if response.status_code == 409:
     response_409 = cast(Any, None)
     return response_409
-  if response.status_code == 500:
-    response_500 = cast(Any, None)
-    return response_500
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = cast(Any, None)
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -100,8 +92,6 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: DeleteSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, DeleteSubgraphResponse, HTTPValidationError]]:
   """Delete Subgraph
 
@@ -125,10 +115,8 @@ def sync_detailed(
   `s3://robosystems-backups/{instance_id}/{database_name}_{timestamp}.backup`
 
   Args:
-      graph_id (str): Parent graph identifier
+      graph_id (str):
       subgraph_id (str): Subgraph identifier to delete
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (DeleteSubgraphRequest): Request model for deleting a subgraph.
 
   Raises:
@@ -143,8 +131,6 @@ def sync_detailed(
     graph_id=graph_id,
     subgraph_id=subgraph_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -160,8 +146,6 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: DeleteSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, DeleteSubgraphResponse, HTTPValidationError]]:
   """Delete Subgraph
 
@@ -185,10 +169,8 @@ def sync(
   `s3://robosystems-backups/{instance_id}/{database_name}_{timestamp}.backup`
 
   Args:
-      graph_id (str): Parent graph identifier
+      graph_id (str):
       subgraph_id (str): Subgraph identifier to delete
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (DeleteSubgraphRequest): Request model for deleting a subgraph.
 
   Raises:
@@ -204,8 +186,6 @@ def sync(
     subgraph_id=subgraph_id,
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -215,8 +195,6 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: DeleteSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, DeleteSubgraphResponse, HTTPValidationError]]:
   """Delete Subgraph
 
@@ -240,10 +218,8 @@ async def asyncio_detailed(
   `s3://robosystems-backups/{instance_id}/{database_name}_{timestamp}.backup`
 
   Args:
-      graph_id (str): Parent graph identifier
+      graph_id (str):
       subgraph_id (str): Subgraph identifier to delete
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (DeleteSubgraphRequest): Request model for deleting a subgraph.
 
   Raises:
@@ -258,8 +234,6 @@ async def asyncio_detailed(
     graph_id=graph_id,
     subgraph_id=subgraph_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -273,8 +247,6 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: DeleteSubgraphRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, DeleteSubgraphResponse, HTTPValidationError]]:
   """Delete Subgraph
 
@@ -298,10 +270,8 @@ async def asyncio(
   `s3://robosystems-backups/{instance_id}/{database_name}_{timestamp}.backup`
 
   Args:
-      graph_id (str): Parent graph identifier
+      graph_id (str):
       subgraph_id (str): Subgraph identifier to delete
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (DeleteSubgraphRequest): Request model for deleting a subgraph.
 
   Raises:
@@ -318,7 +288,5 @@ async def asyncio(
       subgraph_id=subgraph_id,
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
