@@ -7,37 +7,17 @@ from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.http_validation_error import HTTPValidationError
 from ...models.subgraph_quota_response import SubgraphQuotaResponse
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/graphs/{graph_id}/subgraphs/quota",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -48,22 +28,28 @@ def _parse_response(
     response_200 = SubgraphQuotaResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 401:
     response_401 = cast(Any, None)
     return response_401
+
   if response.status_code == 403:
     response_403 = cast(Any, None)
     return response_403
+
   if response.status_code == 404:
     response_404 = cast(Any, None)
     return response_404
-  if response.status_code == 500:
-    response_500 = cast(Any, None)
-    return response_500
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = cast(Any, None)
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -85,8 +71,6 @@ def sync_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, HTTPValidationError, SubgraphQuotaResponse]]:
   """Get Subgraph Quota
 
@@ -109,9 +93,7 @@ def sync_detailed(
   Individual subgraph sizes shown in list endpoint.
 
   Args:
-      graph_id (str): Parent graph identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -123,8 +105,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -138,8 +118,6 @@ def sync(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, HTTPValidationError, SubgraphQuotaResponse]]:
   """Get Subgraph Quota
 
@@ -162,9 +140,7 @@ def sync(
   Individual subgraph sizes shown in list endpoint.
 
   Args:
-      graph_id (str): Parent graph identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -177,8 +153,6 @@ def sync(
   return sync_detailed(
     graph_id=graph_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -186,8 +160,6 @@ async def asyncio_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[Any, HTTPValidationError, SubgraphQuotaResponse]]:
   """Get Subgraph Quota
 
@@ -210,9 +182,7 @@ async def asyncio_detailed(
   Individual subgraph sizes shown in list endpoint.
 
   Args:
-      graph_id (str): Parent graph identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -224,8 +194,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -237,8 +205,6 @@ async def asyncio(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[Any, HTTPValidationError, SubgraphQuotaResponse]]:
   """Get Subgraph Quota
 
@@ -261,9 +227,7 @@ async def asyncio(
   Individual subgraph sizes shown in list endpoint.
 
   Args:
-      graph_id (str): Parent graph identifier
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -277,7 +241,5 @@ async def asyncio(
     await asyncio_detailed(
       graph_id=graph_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
