@@ -7,37 +7,17 @@ from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.http_validation_error import HTTPValidationError
 from ...models.list_subgraphs_response import ListSubgraphsResponse
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   graph_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "get",
     "url": f"/v1/graphs/{graph_id}/subgraphs",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -48,10 +28,12 @@ def _parse_response(
     response_200 = ListSubgraphsResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -73,8 +55,6 @@ def sync_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
   """List Subgraphs
 
@@ -90,9 +70,7 @@ def sync_detailed(
   - Each subgraph includes its ID, name, description, type, status, and creation date
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -104,8 +82,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -119,8 +95,6 @@ def sync(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
   """List Subgraphs
 
@@ -136,9 +110,7 @@ def sync(
   - Each subgraph includes its ID, name, description, type, status, and creation date
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -151,8 +123,6 @@ def sync(
   return sync_detailed(
     graph_id=graph_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -160,8 +130,6 @@ async def asyncio_detailed(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
   """List Subgraphs
 
@@ -177,9 +145,7 @@ async def asyncio_detailed(
   - Each subgraph includes its ID, name, description, type, status, and creation date
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -191,8 +157,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     graph_id=graph_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -204,8 +168,6 @@ async def asyncio(
   graph_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
   """List Subgraphs
 
@@ -221,9 +183,7 @@ async def asyncio(
   - Each subgraph includes its ID, name, description, type, status, and creation date
 
   Args:
-      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
+      graph_id (str):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -237,7 +197,5 @@ async def asyncio(
     await asyncio_detailed(
       graph_id=graph_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
