@@ -8,34 +8,18 @@ from ...client import AuthenticatedClient, Client
 from ...models.create_api_key_request import CreateAPIKeyRequest
 from ...models.create_api_key_response import CreateAPIKeyResponse
 from ...models.http_validation_error import HTTPValidationError
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   *,
   body: CreateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "post",
     "url": "/v1/user/api-keys",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -53,10 +37,12 @@ def _parse_response(
     response_201 = CreateAPIKeyResponse.from_dict(response.json())
 
     return response_201
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -78,16 +64,12 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: CreateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[CreateAPIKeyResponse, HTTPValidationError]]:
   """Create API Key
 
    Create a new API key for the current user.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CreateAPIKeyRequest): Request model for creating a new API key.
 
   Raises:
@@ -100,8 +82,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -115,16 +95,12 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: CreateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[CreateAPIKeyResponse, HTTPValidationError]]:
   """Create API Key
 
    Create a new API key for the current user.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CreateAPIKeyRequest): Request model for creating a new API key.
 
   Raises:
@@ -138,8 +114,6 @@ def sync(
   return sync_detailed(
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -147,16 +121,12 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: CreateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[CreateAPIKeyResponse, HTTPValidationError]]:
   """Create API Key
 
    Create a new API key for the current user.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CreateAPIKeyRequest): Request model for creating a new API key.
 
   Raises:
@@ -169,8 +139,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -182,16 +150,12 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: CreateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[CreateAPIKeyResponse, HTTPValidationError]]:
   """Create API Key
 
    Create a new API key for the current user.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (CreateAPIKeyRequest): Request model for creating a new API key.
 
   Raises:
@@ -206,7 +170,5 @@ async def asyncio(
     await asyncio_detailed(
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
