@@ -8,37 +8,17 @@ from ...client import AuthenticatedClient, Client
 from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
 from ...models.success_response import SuccessResponse
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   api_key_id: str,
-  *,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
-  headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
-
   _kwargs: dict[str, Any] = {
     "method": "delete",
     "url": f"/v1/user/api-keys/{api_key_id}",
-    "params": params,
   }
 
-  _kwargs["headers"] = headers
   return _kwargs
 
 
@@ -49,18 +29,22 @@ def _parse_response(
     response_200 = SuccessResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 404:
     response_404 = ErrorResponse.from_dict(response.json())
 
     return response_404
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -82,8 +66,6 @@ def sync_detailed(
   api_key_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Revoke API Key
 
@@ -91,8 +73,6 @@ def sync_detailed(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -104,8 +84,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     api_key_id=api_key_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -119,8 +97,6 @@ def sync(
   api_key_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Revoke API Key
 
@@ -128,8 +104,6 @@ def sync(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -142,8 +116,6 @@ def sync(
   return sync_detailed(
     api_key_id=api_key_id,
     client=client,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -151,8 +123,6 @@ async def asyncio_detailed(
   api_key_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Revoke API Key
 
@@ -160,8 +130,6 @@ async def asyncio_detailed(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -173,8 +141,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     api_key_id=api_key_id,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -186,8 +152,6 @@ async def asyncio(
   api_key_id: str,
   *,
   client: AuthenticatedClient,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Revoke API Key
 
@@ -195,8 +159,6 @@ async def asyncio(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
 
   Raises:
       errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -210,7 +172,5 @@ async def asyncio(
     await asyncio_detailed(
       api_key_id=api_key_id,
       client=client,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
