@@ -8,35 +8,19 @@ from ...client import AuthenticatedClient, Client
 from ...models.api_key_info import APIKeyInfo
 from ...models.http_validation_error import HTTPValidationError
 from ...models.update_api_key_request import UpdateAPIKeyRequest
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   api_key_id: str,
   *,
   body: UpdateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "put",
     "url": f"/v1/user/api-keys/{api_key_id}",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -54,10 +38,12 @@ def _parse_response(
     response_200 = APIKeyInfo.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -80,8 +66,6 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: UpdateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[APIKeyInfo, HTTPValidationError]]:
   """Update API Key
 
@@ -89,8 +73,6 @@ def sync_detailed(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdateAPIKeyRequest): Request model for updating an API key.
 
   Raises:
@@ -104,8 +86,6 @@ def sync_detailed(
   kwargs = _get_kwargs(
     api_key_id=api_key_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -120,8 +100,6 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: UpdateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[APIKeyInfo, HTTPValidationError]]:
   """Update API Key
 
@@ -129,8 +107,6 @@ def sync(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdateAPIKeyRequest): Request model for updating an API key.
 
   Raises:
@@ -145,8 +121,6 @@ def sync(
     api_key_id=api_key_id,
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -155,8 +129,6 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: UpdateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[APIKeyInfo, HTTPValidationError]]:
   """Update API Key
 
@@ -164,8 +136,6 @@ async def asyncio_detailed(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdateAPIKeyRequest): Request model for updating an API key.
 
   Raises:
@@ -179,8 +149,6 @@ async def asyncio_detailed(
   kwargs = _get_kwargs(
     api_key_id=api_key_id,
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -193,8 +161,6 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: UpdateAPIKeyRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[APIKeyInfo, HTTPValidationError]]:
   """Update API Key
 
@@ -202,8 +168,6 @@ async def asyncio(
 
   Args:
       api_key_id (str):
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdateAPIKeyRequest): Request model for updating an API key.
 
   Raises:
@@ -219,7 +183,5 @@ async def asyncio(
       api_key_id=api_key_id,
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
