@@ -9,34 +9,18 @@ from ...models.error_response import ErrorResponse
 from ...models.http_validation_error import HTTPValidationError
 from ...models.success_response import SuccessResponse
 from ...models.update_password_request import UpdatePasswordRequest
-from ...types import UNSET, Response, Unset
+from ...types import Response
 
 
 def _get_kwargs(
   *,
   body: UpdatePasswordRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> dict[str, Any]:
   headers: dict[str, Any] = {}
-  if not isinstance(authorization, Unset):
-    headers["authorization"] = authorization
-
-  params: dict[str, Any] = {}
-
-  json_token: Union[None, Unset, str]
-  if isinstance(token, Unset):
-    json_token = UNSET
-  else:
-    json_token = token
-  params["token"] = json_token
-
-  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
   _kwargs: dict[str, Any] = {
     "method": "put",
     "url": "/v1/user/password",
-    "params": params,
   }
 
   _kwargs["json"] = body.to_dict()
@@ -54,22 +38,27 @@ def _parse_response(
     response_200 = SuccessResponse.from_dict(response.json())
 
     return response_200
+
   if response.status_code == 400:
     response_400 = ErrorResponse.from_dict(response.json())
 
     return response_400
+
   if response.status_code == 404:
     response_404 = ErrorResponse.from_dict(response.json())
 
     return response_404
-  if response.status_code == 500:
-    response_500 = ErrorResponse.from_dict(response.json())
 
-    return response_500
   if response.status_code == 422:
     response_422 = HTTPValidationError.from_dict(response.json())
 
     return response_422
+
+  if response.status_code == 500:
+    response_500 = ErrorResponse.from_dict(response.json())
+
+    return response_500
+
   if client.raise_on_unexpected_status:
     raise errors.UnexpectedStatus(response.status_code, response.content)
   else:
@@ -91,16 +80,12 @@ def sync_detailed(
   *,
   client: AuthenticatedClient,
   body: UpdatePasswordRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Update Password
 
    Update the current user's password.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdatePasswordRequest): Request model for updating user password.
 
   Raises:
@@ -113,8 +98,6 @@ def sync_detailed(
 
   kwargs = _get_kwargs(
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = client.get_httpx_client().request(
@@ -128,16 +111,12 @@ def sync(
   *,
   client: AuthenticatedClient,
   body: UpdatePasswordRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Update Password
 
    Update the current user's password.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdatePasswordRequest): Request model for updating user password.
 
   Raises:
@@ -151,8 +130,6 @@ def sync(
   return sync_detailed(
     client=client,
     body=body,
-    token=token,
-    authorization=authorization,
   ).parsed
 
 
@@ -160,16 +137,12 @@ async def asyncio_detailed(
   *,
   client: AuthenticatedClient,
   body: UpdatePasswordRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Response[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Update Password
 
    Update the current user's password.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdatePasswordRequest): Request model for updating user password.
 
   Raises:
@@ -182,8 +155,6 @@ async def asyncio_detailed(
 
   kwargs = _get_kwargs(
     body=body,
-    token=token,
-    authorization=authorization,
   )
 
   response = await client.get_async_httpx_client().request(**kwargs)
@@ -195,16 +166,12 @@ async def asyncio(
   *,
   client: AuthenticatedClient,
   body: UpdatePasswordRequest,
-  token: Union[None, Unset, str] = UNSET,
-  authorization: Union[None, Unset, str] = UNSET,
 ) -> Optional[Union[ErrorResponse, HTTPValidationError, SuccessResponse]]:
   """Update Password
 
    Update the current user's password.
 
   Args:
-      token (Union[None, Unset, str]): JWT token for SSE authentication
-      authorization (Union[None, Unset, str]):
       body (UpdatePasswordRequest): Request model for updating user password.
 
   Raises:
@@ -219,7 +186,5 @@ async def asyncio(
     await asyncio_detailed(
       client=client,
       body=body,
-      token=token,
-      authorization=authorization,
     )
   ).parsed
