@@ -20,13 +20,18 @@ from .operation_client import (
   OperationProgress,
   OperationResult,
 )
-from .copy_client import (
-  CopyClient,
-  AsyncCopyClient,
-  CopySourceType,
-  CopyOptions,
-  CopyResult,
-  CopyStatistics,
+from .table_ingest_client import (
+  TableIngestClient,
+  UploadOptions,
+  IngestOptions,
+  UploadResult,
+  TableInfo,
+)
+from .graph_client import (
+  GraphClient,
+  GraphMetadata,
+  InitialEntityData,
+  GraphInfo,
 )
 from .extensions import (
   RoboSystemsExtensions,
@@ -89,6 +94,7 @@ except ImportError:
   HAS_PANDAS = False
   DataFrameQueryClient = None
   # Set placeholders for optional functions
+  query_result_to_dataframe = None
   parse_datetime_columns = None
   _stream_to_dataframe = None
   dataframe_to_cypher_params = None
@@ -117,13 +123,17 @@ __all__ = [
   "OperationStatus",
   "OperationProgress",
   "OperationResult",
-  # Copy Client
-  "CopyClient",
-  "AsyncCopyClient",
-  "CopySourceType",
-  "CopyOptions",
-  "CopyResult",
-  "CopyStatistics",
+  # Table Ingest Client
+  "TableIngestClient",
+  "UploadOptions",
+  "IngestOptions",
+  "UploadResult",
+  "TableInfo",
+  # Graph Client
+  "GraphClient",
+  "GraphMetadata",
+  "InitialEntityData",
+  "GraphInfo",
   # Utilities
   "QueryBuilder",
   "ResultProcessor",
@@ -179,29 +189,21 @@ def stream_query(graph_id: str, query: str, parameters=None, chunk_size=None):
   return extensions.query.stream_query(graph_id, query, parameters, chunk_size)
 
 
-def copy_from_s3(
-  graph_id: str,
-  table_name: str,
-  s3_path: str,
-  access_key_id: str,
-  secret_access_key: str,
-  **kwargs,
-):
-  """Copy data from S3 using the default extensions instance"""
-  return extensions.copy_from_s3(
-    graph_id, table_name, s3_path, access_key_id, secret_access_key, **kwargs
-  )
-
-
 # DataFrame convenience functions (if pandas is available)
-if HAS_PANDAS:
+if (
+  HAS_PANDAS
+  and query_result_to_dataframe is not None
+  and _stream_to_dataframe is not None
+):
 
   def query_to_dataframe(graph_id: str, query: str, parameters=None, **kwargs):
     """Execute query and return results as pandas DataFrame"""
+    assert query_result_to_dataframe is not None
     result = execute_query(graph_id, query, parameters)
     return query_result_to_dataframe(result, **kwargs)
 
   def stream_to_dataframe(graph_id: str, query: str, parameters=None, chunk_size=10000):
     """Stream query results and return as pandas DataFrame"""
+    assert _stream_to_dataframe is not None
     stream = stream_query(graph_id, query, parameters, chunk_size)
     return _stream_to_dataframe(stream, chunk_size)
