@@ -8,7 +8,8 @@ from typing import Dict, Any, Optional, Callable
 
 from .query_client import QueryClient
 from .operation_client import OperationClient
-from .copy_client import CopyClient
+from .table_ingest_client import TableIngestClient
+from .graph_client import GraphClient
 from .sse_client import SSEClient
 
 
@@ -56,9 +57,10 @@ class RoboSystemsExtensions:
       self.config["token"] = token
 
     # Initialize clients
-    self.copy = CopyClient(self.config)
     self.query = QueryClient(self.config)
     self.operations = OperationClient(self.config)
+    self.tables = TableIngestClient(self.config)
+    self.graphs = GraphClient(self.config)
 
   def monitor_operation(
     self, operation_id: str, on_progress: Optional[Callable] = None
@@ -85,9 +87,10 @@ class RoboSystemsExtensions:
 
   def close(self):
     """Clean up all active connections"""
-    self.copy.close()
     self.query.close()
     self.operations.close_all()
+    self.tables.close()
+    self.graphs.close()
 
   # Convenience methods that delegate to the appropriate clients
   def execute_query(self, graph_id: str, query: str, parameters: Dict[str, Any] = None):
@@ -112,20 +115,6 @@ class RoboSystemsExtensions:
     """Cancel an operation using the operation client"""
     return self.operations.cancel_operation(operation_id)
 
-  def copy_from_s3(
-    self,
-    graph_id: str,
-    table_name: str,
-    s3_path: str,
-    access_key_id: str,
-    secret_access_key: str,
-    **kwargs,
-  ):
-    """Copy data from S3 using the copy client"""
-    return self.copy.copy_s3(
-      graph_id, table_name, s3_path, access_key_id, secret_access_key, **kwargs
-    )
-
 
 class AsyncRoboSystemsExtensions:
   """Async version of the extensions class"""
