@@ -98,47 +98,143 @@ class QueryClient:
     )
 
     # Execute the query through the generated client
-    from ..client import Client
+    from ..client import AuthenticatedClient
 
-    # Create client with headers
-    client = Client(base_url=self.base_url, headers=self.headers)
+    # Create authenticated client with X-API-Key
+    if not self.token:
+      raise Exception("No API key provided. Set X-API-Key in headers.")
+
+    client = AuthenticatedClient(
+      base_url=self.base_url,
+      token=self.token,
+      prefix="",
+      auth_header_name="X-API-Key",
+      headers=self.headers,
+    )
 
     try:
-      kwargs = {"graph_id": graph_id, "client": client, "body": query_request}
-      # Only add token if it's a valid string
-      if self.token and isinstance(self.token, str) and self.token.strip():
-        kwargs["token"] = self.token
+      kwargs = {
+        "graph_id": graph_id,
+        "client": client,
+        "body": query_request,
+        "mode": options.mode if options.mode else None,
+        "chunk_size": options.chunk_size if options.chunk_size else 1000,
+        "test_mode": options.test_mode if options.test_mode else False,
+      }
       response = execute_cypher_query(**kwargs)
 
+      # Check if this is an NDJSON streaming response (parsed will be None for NDJSON)
+      if (
+        hasattr(response, "headers")
+        and (
+          "application/x-ndjson" in response.headers.get("content-type", "")
+          or response.headers.get("x-stream-format") == "ndjson"
+        )
+      ) or (
+        hasattr(response, "parsed")
+        and response.parsed is None
+        and response.status_code == 200
+      ):
+        return self._parse_ndjson_response(response, graph_id)
+
       # Check response type and handle accordingly
       if hasattr(response, "parsed") and response.parsed:
         response_data = response.parsed
 
+        # Handle both dict and attrs object responses
+        if isinstance(response_data, dict):
+          # Response is a plain dict
+          data = response_data
+          has_data = "data" in data and "columns" in data
+        else:
+          # Response is an attrs object - check for attributes directly
+          data = response_data
+          has_data = hasattr(data, "data") and hasattr(data, "columns")
+
         # Check if this is an immediate response
-        if hasattr(response_data, "data") and hasattr(response_data, "columns"):
+        if has_data:
+          # Extract data from either dict or attrs object
+          if isinstance(data, dict):
+            result_data = data["data"]
+            result_columns = data["columns"]
+            result_row_count = data.get("row_count", len(data["data"]))
+            result_execution_time = data.get("execution_time_ms", 0)
+            result_timestamp = data.get("timestamp", datetime.now().isoformat())
+          else:
+            # attrs object - access attributes directly
+            from ..types import UNSET
+
+            raw_data = data.data if data.data is not UNSET else []
+            # Convert data items to dicts if they're objects
+            result_data = []
+            for item in raw_data:
+              if hasattr(item, "to_dict"):
+                result_data.append(item.to_dict())
+              elif hasattr(item, "additional_properties"):
+                result_data.append(item.additional_properties)
+              else:
+                result_data.append(item)
+            result_columns = data.columns if data.columns is not UNSET else []
+            result_row_count = (
+              data.row_count if data.row_count is not UNSET else len(result_data)
+            )
+            result_execution_time = (
+              data.execution_time_ms if data.execution_time_ms is not UNSET else 0
+            )
+            result_timestamp = (
+              data.timestamp
+              if data.timestamp is not UNSET
+              else datetime.now().isoformat()
+            )
+
           return QueryResult(
-            data=response_data.data,
-            columns=response_data.columns,
-            row_count=getattr(response_data, "row_count", len(response_data.data)),
-            execution_time_ms=getattr(response_data, "execution_time_ms", 0),
+            data=result_data,
+            columns=result_columns,
+            row_count=result_row_count,
+            execution_time_ms=result_execution_time,
             graph_id=graph_id,
-            timestamp=getattr(response_data, "timestamp", datetime.now().isoformat()),
+            timestamp=result_timestamp,
           )
 
         # Check if this is a queued response
-        if (
-          hasattr(response_data, "status")
-          and response_data.status == "queued"
-          and hasattr(response_data, "operation_id")
-        ):
-          queued_response = QueuedQueryResponse(
-            status=response_data.status,
-            operation_id=response_data.operation_id,
-            queue_position=getattr(response_data, "queue_position", 0),
-            estimated_wait_seconds=getattr(response_data, "estimated_wait_seconds", 0),
-            message=getattr(response_data, "message", "Query queued"),
-          )
+        is_queued = False
+        queued_response = None
 
+        if isinstance(data, dict):
+          is_queued = data.get("status") == "queued" and "operation_id" in data
+          if is_queued:
+            queued_response = QueuedQueryResponse(
+              status=data["status"],
+              operation_id=data["operation_id"],
+              queue_position=data.get("queue_position", 0),
+              estimated_wait_seconds=data.get("estimated_wait_seconds", 0),
+              message=data.get("message", "Query queued"),
+            )
+        else:
+          is_queued = (
+            hasattr(data, "status")
+            and hasattr(data, "operation_id")
+            and getattr(data, "status", None) == "queued"
+          )
+          if is_queued:
+            from ..types import UNSET
+
+            queued_response = QueuedQueryResponse(
+              status=data.status,
+              operation_id=data.operation_id,
+              queue_position=data.queue_position
+              if hasattr(data, "queue_position") and data.queue_position is not UNSET
+              else 0,
+              estimated_wait_seconds=data.estimated_wait_seconds
+              if hasattr(data, "estimated_wait_seconds")
+              and data.estimated_wait_seconds is not UNSET
+              else 0,
+              message=data.message
+              if hasattr(data, "message") and data.message is not UNSET
+              else "Query queued",
+            )
+
+        if is_queued and queued_response:
           # Notify about queue status
           if options.on_queue_update:
             options.on_queue_update(
@@ -173,6 +269,58 @@ class QueryClient:
     # Unexpected response format
     raise Exception("Unexpected response format from query endpoint")
 
+  def _parse_ndjson_response(self, response, graph_id: str) -> QueryResult:
+    """Parse NDJSON streaming response and aggregate into QueryResult"""
+    import json
+
+    all_data = []
+    columns = None
+    total_rows = 0
+    execution_time_ms = 0
+
+    # Parse NDJSON line by line
+    content = (
+      response.content.decode("utf-8")
+      if isinstance(response.content, bytes)
+      else response.content
+    )
+
+    for line in content.strip().split("\n"):
+      if not line.strip():
+        continue
+
+      try:
+        chunk = json.loads(line)
+
+        # Extract columns from first chunk
+        if columns is None and "columns" in chunk:
+          columns = chunk["columns"]
+
+        # Aggregate data rows (NDJSON uses "rows", regular JSON uses "data")
+        if "rows" in chunk:
+          all_data.extend(chunk["rows"])
+          total_rows += len(chunk["rows"])
+        elif "data" in chunk:
+          all_data.extend(chunk["data"])
+          total_rows += len(chunk["data"])
+
+        # Track execution time (use max from all chunks)
+        if "execution_time_ms" in chunk:
+          execution_time_ms = max(execution_time_ms, chunk["execution_time_ms"])
+
+      except json.JSONDecodeError as e:
+        raise Exception(f"Failed to parse NDJSON line: {e}")
+
+    # Return aggregated result
+    return QueryResult(
+      data=all_data,
+      columns=columns or [],
+      row_count=total_rows,
+      execution_time_ms=execution_time_ms,
+      graph_id=graph_id,
+      timestamp=datetime.now().isoformat(),
+    )
+
   def _stream_query_results(
     self, operation_id: str, options: QueryOptions
   ) -> Iterator[Any]:
@@ -182,7 +330,7 @@ class QueryClient:
     error = None
 
     # Set up SSE connection
-    sse_config = SSEConfig(base_url=self.base_url)
+    sse_config = SSEConfig(base_url=self.base_url, headers=self.headers)
     self.sse_client = SSEClient(sse_config)
 
     # Set up event handlers
@@ -389,7 +537,7 @@ class QueryClient:
     self,
     graph_id: str,
     queries: List[str],
-    parameters_list: Optional[List[Dict[str, Any]]] = None,
+    parameters_list: Optional[List[Optional[Dict[str, Any]]]] = None,
     parallel: bool = False,
   ) -> List[Union[QueryResult, Dict[str, Any]]]:
     """Execute multiple queries in batch
@@ -410,7 +558,8 @@ class QueryClient:
         ... ])
     """
     if parameters_list is None:
-      parameters_list = [None] * len(queries)
+      # Create a list of None values for each query
+      parameters_list = [None for _ in queries]
 
     if len(queries) != len(parameters_list):
       raise ValueError("queries and parameters_list must have same length")
