@@ -1,7 +1,6 @@
 """Contains all the data models used in inputs/outputs"""
 
 from .account_info import AccountInfo
-from .add_on_credit_info import AddOnCreditInfo
 from .agent_list_response import AgentListResponse
 from .agent_list_response_agents import AgentListResponseAgents
 from .agent_list_response_agents_additional_property import (
@@ -28,7 +27,10 @@ from .auth_response import AuthResponse
 from .auth_response_user import AuthResponseUser
 from .available_extension import AvailableExtension
 from .available_extensions_response import AvailableExtensionsResponse
+from .available_graph_tiers_response import AvailableGraphTiersResponse
 from .backup_create_request import BackupCreateRequest
+from .backup_download_url_response import BackupDownloadUrlResponse
+from .backup_limits import BackupLimits
 from .backup_list_response import BackupListResponse
 from .backup_response import BackupResponse
 from .backup_restore_request import BackupRestoreRequest
@@ -36,6 +38,8 @@ from .backup_stats_response import BackupStatsResponse
 from .backup_stats_response_backup_formats import BackupStatsResponseBackupFormats
 from .batch_agent_request import BatchAgentRequest
 from .batch_agent_response import BatchAgentResponse
+from .bulk_ingest_request import BulkIngestRequest
+from .bulk_ingest_response import BulkIngestResponse
 from .cancel_operation_response_canceloperation import (
   CancelOperationResponseCanceloperation,
 )
@@ -50,22 +54,19 @@ from .connection_provider_info_provider import ConnectionProviderInfoProvider
 from .connection_response import ConnectionResponse
 from .connection_response_metadata import ConnectionResponseMetadata
 from .connection_response_provider import ConnectionResponseProvider
-from .copy_response import CopyResponse
-from .copy_response_error_details_type_0 import CopyResponseErrorDetailsType0
-from .copy_response_status import CopyResponseStatus
+from .copy_operation_limits import CopyOperationLimits
 from .create_api_key_request import CreateAPIKeyRequest
 from .create_api_key_response import CreateAPIKeyResponse
 from .create_connection_request import CreateConnectionRequest
 from .create_connection_request_provider import CreateConnectionRequestProvider
 from .create_graph_request import CreateGraphRequest
+from .create_repository_subscription_request import CreateRepositorySubscriptionRequest
 from .create_subgraph_request import CreateSubgraphRequest
 from .create_subgraph_request_metadata_type_0 import CreateSubgraphRequestMetadataType0
+from .credit_limits import CreditLimits
 from .credit_summary import CreditSummary
+from .credit_summary_operation_breakdown import CreditSummaryOperationBreakdown
 from .credit_summary_response import CreditSummaryResponse
-from .credits_summary_response import CreditsSummaryResponse
-from .credits_summary_response_credits_by_addon_type_0_item import (
-  CreditsSummaryResponseCreditsByAddonType0Item,
-)
 from .custom_schema_definition import CustomSchemaDefinition
 from .custom_schema_definition_metadata import CustomSchemaDefinitionMetadata
 from .custom_schema_definition_nodes_item import CustomSchemaDefinitionNodesItem
@@ -74,10 +75,9 @@ from .custom_schema_definition_relationships_item import (
 )
 from .cypher_query_request import CypherQueryRequest
 from .cypher_query_request_parameters_type_0 import CypherQueryRequestParametersType0
-from .data_frame_copy_request import DataFrameCopyRequest
-from .data_frame_copy_request_format import DataFrameCopyRequestFormat
 from .database_health_response import DatabaseHealthResponse
 from .database_info_response import DatabaseInfoResponse
+from .delete_file_response import DeleteFileResponse
 from .delete_subgraph_request import DeleteSubgraphRequest
 from .delete_subgraph_response import DeleteSubgraphResponse
 from .detailed_transactions_response import DetailedTransactionsResponse
@@ -93,50 +93,30 @@ from .enhanced_credit_transaction_response_metadata import (
 from .error_response import ErrorResponse
 from .exchange_token_request import ExchangeTokenRequest
 from .exchange_token_request_metadata_type_0 import ExchangeTokenRequestMetadataType0
+from .execute_cypher_query_response_200 import ExecuteCypherQueryResponse200
+from .execute_cypher_query_response_200_data_item import (
+  ExecuteCypherQueryResponse200DataItem,
+)
+from .file_info import FileInfo
+from .file_status_update import FileStatusUpdate
+from .file_upload_request import FileUploadRequest
+from .file_upload_response import FileUploadResponse
 from .forgot_password_request import ForgotPasswordRequest
 from .forgot_password_response_forgotpassword import (
   ForgotPasswordResponseForgotpassword,
 )
-from .get_all_credit_summaries_response_getallcreditsummaries import (
-  GetAllCreditSummariesResponseGetallcreditsummaries,
-)
-from .get_all_shared_repository_limits_response_getallsharedrepositorylimits import (
-  GetAllSharedRepositoryLimitsResponseGetallsharedrepositorylimits,
-)
-from .get_backup_download_url_response_getbackupdownloadurl import (
-  GetBackupDownloadUrlResponseGetbackupdownloadurl,
-)
 from .get_current_auth_user_response_getcurrentauthuser import (
   GetCurrentAuthUserResponseGetcurrentauthuser,
 )
-from .get_current_graph_bill_response_getcurrentgraphbill import (
-  GetCurrentGraphBillResponseGetcurrentgraphbill,
-)
-from .get_graph_billing_history_response_getgraphbillinghistory import (
-  GetGraphBillingHistoryResponseGetgraphbillinghistory,
-)
-from .get_graph_limits_response_getgraphlimits import (
-  GetGraphLimitsResponseGetgraphlimits,
-)
-from .get_graph_monthly_bill_response_getgraphmonthlybill import (
-  GetGraphMonthlyBillResponseGetgraphmonthlybill,
-)
-from .get_graph_schema_info_response_getgraphschemainfo import (
-  GetGraphSchemaInfoResponseGetgraphschemainfo,
-)
-from .get_graph_usage_details_response_getgraphusagedetails import (
-  GetGraphUsageDetailsResponseGetgraphusagedetails,
-)
+from .get_file_info_response import GetFileInfoResponse
 from .get_operation_status_response_getoperationstatus import (
   GetOperationStatusResponseGetoperationstatus,
 )
-from .get_shared_repository_limits_response_getsharedrepositorylimits import (
-  GetSharedRepositoryLimitsResponseGetsharedrepositorylimits,
-)
 from .get_storage_usage_response_getstorageusage import (
   GetStorageUsageResponseGetstorageusage,
 )
 from .graph_info import GraphInfo
+from .graph_limits_response import GraphLimitsResponse
 from .graph_metadata import GraphMetadata
 from .graph_metrics_response import GraphMetricsResponse
 from .graph_metrics_response_estimated_size import GraphMetricsResponseEstimatedSize
@@ -145,10 +125,16 @@ from .graph_metrics_response_node_counts import GraphMetricsResponseNodeCounts
 from .graph_metrics_response_relationship_counts import (
   GraphMetricsResponseRelationshipCounts,
 )
+from .graph_subscription_response import GraphSubscriptionResponse
+from .graph_subscription_tier import GraphSubscriptionTier
+from .graph_subscriptions import GraphSubscriptions
+from .graph_tier_backup import GraphTierBackup
+from .graph_tier_copy_operations import GraphTierCopyOperations
+from .graph_tier_info import GraphTierInfo
+from .graph_tier_instance import GraphTierInstance
+from .graph_tier_limits import GraphTierLimits
 from .graph_usage_response import GraphUsageResponse
-from .graph_usage_response_query_statistics import GraphUsageResponseQueryStatistics
-from .graph_usage_response_recent_activity import GraphUsageResponseRecentActivity
-from .graph_usage_response_storage_usage import GraphUsageResponseStorageUsage
+from .graph_usage_response_recent_events_item import GraphUsageResponseRecentEventsItem
 from .health_status import HealthStatus
 from .health_status_details_type_0 import HealthStatusDetailsType0
 from .http_validation_error import HTTPValidationError
@@ -157,10 +143,8 @@ from .link_token_request import LinkTokenRequest
 from .link_token_request_options_type_0 import LinkTokenRequestOptionsType0
 from .link_token_request_provider_type_0 import LinkTokenRequestProviderType0
 from .list_connections_provider_type_0 import ListConnectionsProviderType0
-from .list_schema_extensions_response_listschemaextensions import (
-  ListSchemaExtensionsResponseListschemaextensions,
-)
 from .list_subgraphs_response import ListSubgraphsResponse
+from .list_table_files_response import ListTableFilesResponse
 from .login_request import LoginRequest
 from .logout_user_response_logoutuser import LogoutUserResponseLogoutuser
 from .mcp_tool_call import MCPToolCall
@@ -173,11 +157,21 @@ from .o_auth_init_request_additional_params_type_0 import (
   OAuthInitRequestAdditionalParamsType0,
 )
 from .o_auth_init_response import OAuthInitResponse
+from .offering_repository_plan import OfferingRepositoryPlan
+from .offering_repository_plan_rate_limits_type_0 import (
+  OfferingRepositoryPlanRateLimitsType0,
+)
+from .operation_costs import OperationCosts
+from .operation_costs_ai_operations import OperationCostsAiOperations
+from .operation_costs_token_pricing import OperationCostsTokenPricing
 from .password_check_request import PasswordCheckRequest
 from .password_check_response import PasswordCheckResponse
 from .password_check_response_character_types import PasswordCheckResponseCharacterTypes
 from .password_policy_response import PasswordPolicyResponse
 from .password_policy_response_policy import PasswordPolicyResponsePolicy
+from .performance_insights import PerformanceInsights
+from .performance_insights_operation_stats import PerformanceInsightsOperationStats
+from .performance_insights_slow_queries_item import PerformanceInsightsSlowQueriesItem
 from .plaid_connection_config import PlaidConnectionConfig
 from .plaid_connection_config_accounts_type_0_item import (
   PlaidConnectionConfigAccountsType0Item,
@@ -185,25 +179,25 @@ from .plaid_connection_config_accounts_type_0_item import (
 from .plaid_connection_config_institution_type_0 import (
   PlaidConnectionConfigInstitutionType0,
 )
+from .query_limits import QueryLimits
 from .quick_books_connection_config import QuickBooksConnectionConfig
+from .rate_limits import RateLimits
 from .register_request import RegisterRequest
-from .repository_credits_response import RepositoryCreditsResponse
-from .repository_plan import RepositoryPlan
-from .repository_type import RepositoryType
+from .repository_info import RepositoryInfo
+from .repository_subscriptions import RepositorySubscriptions
 from .resend_verification_email_response_resendverificationemail import (
   ResendVerificationEmailResponseResendverificationemail,
 )
 from .reset_password_request import ResetPasswordRequest
 from .reset_password_validate_response import ResetPasswordValidateResponse
 from .response_mode import ResponseMode
-from .s3_copy_request import S3CopyRequest
-from .s3_copy_request_file_format import S3CopyRequestFileFormat
-from .s3_copy_request_s3_url_style_type_0 import S3CopyRequestS3UrlStyleType0
 from .schema_export_response import SchemaExportResponse
 from .schema_export_response_data_stats_type_0 import SchemaExportResponseDataStatsType0
 from .schema_export_response_schema_definition_type_0 import (
   SchemaExportResponseSchemaDefinitionType0,
 )
+from .schema_info_response import SchemaInfoResponse
+from .schema_info_response_schema import SchemaInfoResponseSchema
 from .schema_validation_request import SchemaValidationRequest
 from .schema_validation_request_schema_definition_type_0 import (
   SchemaValidationRequestSchemaDefinitionType0,
@@ -215,20 +209,23 @@ from .schema_validation_response_compatibility_type_0 import (
 from .schema_validation_response_stats_type_0 import SchemaValidationResponseStatsType0
 from .sec_connection_config import SECConnectionConfig
 from .selection_criteria import SelectionCriteria
+from .service_offering_summary import ServiceOfferingSummary
+from .service_offerings_response import ServiceOfferingsResponse
 from .sso_complete_request import SSOCompleteRequest
 from .sso_exchange_request import SSOExchangeRequest
 from .sso_exchange_response import SSOExchangeResponse
 from .sso_token_response import SSOTokenResponse
+from .storage_info import StorageInfo
+from .storage_info_included_per_tier import StorageInfoIncludedPerTier
+from .storage_info_overage_pricing import StorageInfoOveragePricing
 from .storage_limit_response import StorageLimitResponse
+from .storage_limits import StorageLimits
+from .storage_summary import StorageSummary
 from .subgraph_quota_response import SubgraphQuotaResponse
 from .subgraph_response import SubgraphResponse
 from .subgraph_response_metadata_type_0 import SubgraphResponseMetadataType0
 from .subgraph_summary import SubgraphSummary
 from .subgraph_type import SubgraphType
-from .subscription_info import SubscriptionInfo
-from .subscription_info_metadata import SubscriptionInfoMetadata
-from .subscription_request import SubscriptionRequest
-from .subscription_response import SubscriptionResponse
 from .success_response import SuccessResponse
 from .success_response_data_type_0 import SuccessResponseDataType0
 from .sync_connection_request import SyncConnectionRequest
@@ -238,38 +235,29 @@ from .sync_connection_request_sync_options_type_0 import (
 from .sync_connection_response_syncconnection import (
   SyncConnectionResponseSyncconnection,
 )
-from .tier_upgrade_request import TierUpgradeRequest
+from .table_info import TableInfo
+from .table_ingest_result import TableIngestResult
+from .table_list_response import TableListResponse
+from .table_query_request import TableQueryRequest
+from .table_query_response import TableQueryResponse
+from .token_pricing import TokenPricing
 from .transaction_summary_response import TransactionSummaryResponse
 from .update_api_key_request import UpdateAPIKeyRequest
+from .update_file_status_response_updatefilestatus import (
+  UpdateFileStatusResponseUpdatefilestatus,
+)
 from .update_password_request import UpdatePasswordRequest
 from .update_user_request import UpdateUserRequest
-from .url_copy_request import URLCopyRequest
-from .url_copy_request_file_format import URLCopyRequestFileFormat
-from .url_copy_request_headers_type_0 import URLCopyRequestHeadersType0
-from .user_analytics_response import UserAnalyticsResponse
-from .user_analytics_response_api_usage import UserAnalyticsResponseApiUsage
-from .user_analytics_response_graph_usage import UserAnalyticsResponseGraphUsage
-from .user_analytics_response_limits import UserAnalyticsResponseLimits
-from .user_analytics_response_recent_activity_item import (
-  UserAnalyticsResponseRecentActivityItem,
-)
-from .user_analytics_response_user_info import UserAnalyticsResponseUserInfo
-from .user_graph_summary import UserGraphSummary
+from .upgrade_subscription_request import UpgradeSubscriptionRequest
 from .user_graphs_response import UserGraphsResponse
 from .user_limits_response import UserLimitsResponse
 from .user_response import UserResponse
-from .user_subscriptions_response import UserSubscriptionsResponse
 from .user_usage_response import UserUsageResponse
 from .user_usage_response_graphs import UserUsageResponseGraphs
-from .user_usage_summary_response import UserUsageSummaryResponse
-from .user_usage_summary_response_usage_vs_limits import (
-  UserUsageSummaryResponseUsageVsLimits,
-)
 from .validation_error import ValidationError
 
 __all__ = (
   "AccountInfo",
-  "AddOnCreditInfo",
   "AgentListResponse",
   "AgentListResponseAgents",
   "AgentListResponseAgentsAdditionalProperty",
@@ -292,7 +280,10 @@ __all__ = (
   "AuthResponseUser",
   "AvailableExtension",
   "AvailableExtensionsResponse",
+  "AvailableGraphTiersResponse",
   "BackupCreateRequest",
+  "BackupDownloadUrlResponse",
+  "BackupLimits",
   "BackupListResponse",
   "BackupResponse",
   "BackupRestoreRequest",
@@ -300,6 +291,8 @@ __all__ = (
   "BackupStatsResponseBackupFormats",
   "BatchAgentRequest",
   "BatchAgentResponse",
+  "BulkIngestRequest",
+  "BulkIngestResponse",
   "CancellationResponse",
   "CancelOperationResponseCanceloperation",
   "CheckCreditBalanceResponseCheckcreditbalance",
@@ -310,19 +303,18 @@ __all__ = (
   "ConnectionResponse",
   "ConnectionResponseMetadata",
   "ConnectionResponseProvider",
-  "CopyResponse",
-  "CopyResponseErrorDetailsType0",
-  "CopyResponseStatus",
+  "CopyOperationLimits",
   "CreateAPIKeyRequest",
   "CreateAPIKeyResponse",
   "CreateConnectionRequest",
   "CreateConnectionRequestProvider",
   "CreateGraphRequest",
+  "CreateRepositorySubscriptionRequest",
   "CreateSubgraphRequest",
   "CreateSubgraphRequestMetadataType0",
-  "CreditsSummaryResponse",
-  "CreditsSummaryResponseCreditsByAddonType0Item",
+  "CreditLimits",
   "CreditSummary",
+  "CreditSummaryOperationBreakdown",
   "CreditSummaryResponse",
   "CustomSchemaDefinition",
   "CustomSchemaDefinitionMetadata",
@@ -332,8 +324,7 @@ __all__ = (
   "CypherQueryRequestParametersType0",
   "DatabaseHealthResponse",
   "DatabaseInfoResponse",
-  "DataFrameCopyRequest",
-  "DataFrameCopyRequestFormat",
+  "DeleteFileResponse",
   "DeleteSubgraphRequest",
   "DeleteSubgraphResponse",
   "DetailedTransactionsResponse",
@@ -345,32 +336,36 @@ __all__ = (
   "ErrorResponse",
   "ExchangeTokenRequest",
   "ExchangeTokenRequestMetadataType0",
+  "ExecuteCypherQueryResponse200",
+  "ExecuteCypherQueryResponse200DataItem",
+  "FileInfo",
+  "FileStatusUpdate",
+  "FileUploadRequest",
+  "FileUploadResponse",
   "ForgotPasswordRequest",
   "ForgotPasswordResponseForgotpassword",
-  "GetAllCreditSummariesResponseGetallcreditsummaries",
-  "GetAllSharedRepositoryLimitsResponseGetallsharedrepositorylimits",
-  "GetBackupDownloadUrlResponseGetbackupdownloadurl",
   "GetCurrentAuthUserResponseGetcurrentauthuser",
-  "GetCurrentGraphBillResponseGetcurrentgraphbill",
-  "GetGraphBillingHistoryResponseGetgraphbillinghistory",
-  "GetGraphLimitsResponseGetgraphlimits",
-  "GetGraphMonthlyBillResponseGetgraphmonthlybill",
-  "GetGraphSchemaInfoResponseGetgraphschemainfo",
-  "GetGraphUsageDetailsResponseGetgraphusagedetails",
+  "GetFileInfoResponse",
   "GetOperationStatusResponseGetoperationstatus",
-  "GetSharedRepositoryLimitsResponseGetsharedrepositorylimits",
   "GetStorageUsageResponseGetstorageusage",
   "GraphInfo",
+  "GraphLimitsResponse",
   "GraphMetadata",
   "GraphMetricsResponse",
   "GraphMetricsResponseEstimatedSize",
   "GraphMetricsResponseHealthStatus",
   "GraphMetricsResponseNodeCounts",
   "GraphMetricsResponseRelationshipCounts",
+  "GraphSubscriptionResponse",
+  "GraphSubscriptions",
+  "GraphSubscriptionTier",
+  "GraphTierBackup",
+  "GraphTierCopyOperations",
+  "GraphTierInfo",
+  "GraphTierInstance",
+  "GraphTierLimits",
   "GraphUsageResponse",
-  "GraphUsageResponseQueryStatistics",
-  "GraphUsageResponseRecentActivity",
-  "GraphUsageResponseStorageUsage",
+  "GraphUsageResponseRecentEventsItem",
   "HealthStatus",
   "HealthStatusDetailsType0",
   "HTTPValidationError",
@@ -379,8 +374,8 @@ __all__ = (
   "LinkTokenRequestOptionsType0",
   "LinkTokenRequestProviderType0",
   "ListConnectionsProviderType0",
-  "ListSchemaExtensionsResponseListschemaextensions",
   "ListSubgraphsResponse",
+  "ListTableFilesResponse",
   "LoginRequest",
   "LogoutUserResponseLogoutuser",
   "MCPToolCall",
@@ -391,29 +386,37 @@ __all__ = (
   "OAuthInitRequest",
   "OAuthInitRequestAdditionalParamsType0",
   "OAuthInitResponse",
+  "OfferingRepositoryPlan",
+  "OfferingRepositoryPlanRateLimitsType0",
+  "OperationCosts",
+  "OperationCostsAiOperations",
+  "OperationCostsTokenPricing",
   "PasswordCheckRequest",
   "PasswordCheckResponse",
   "PasswordCheckResponseCharacterTypes",
   "PasswordPolicyResponse",
   "PasswordPolicyResponsePolicy",
+  "PerformanceInsights",
+  "PerformanceInsightsOperationStats",
+  "PerformanceInsightsSlowQueriesItem",
   "PlaidConnectionConfig",
   "PlaidConnectionConfigAccountsType0Item",
   "PlaidConnectionConfigInstitutionType0",
+  "QueryLimits",
   "QuickBooksConnectionConfig",
+  "RateLimits",
   "RegisterRequest",
-  "RepositoryCreditsResponse",
-  "RepositoryPlan",
-  "RepositoryType",
+  "RepositoryInfo",
+  "RepositorySubscriptions",
   "ResendVerificationEmailResponseResendverificationemail",
   "ResetPasswordRequest",
   "ResetPasswordValidateResponse",
   "ResponseMode",
-  "S3CopyRequest",
-  "S3CopyRequestFileFormat",
-  "S3CopyRequestS3UrlStyleType0",
   "SchemaExportResponse",
   "SchemaExportResponseDataStatsType0",
   "SchemaExportResponseSchemaDefinitionType0",
+  "SchemaInfoResponse",
+  "SchemaInfoResponseSchema",
   "SchemaValidationRequest",
   "SchemaValidationRequestSchemaDefinitionType0",
   "SchemaValidationResponse",
@@ -421,47 +424,44 @@ __all__ = (
   "SchemaValidationResponseStatsType0",
   "SECConnectionConfig",
   "SelectionCriteria",
+  "ServiceOfferingsResponse",
+  "ServiceOfferingSummary",
   "SSOCompleteRequest",
   "SSOExchangeRequest",
   "SSOExchangeResponse",
   "SSOTokenResponse",
+  "StorageInfo",
+  "StorageInfoIncludedPerTier",
+  "StorageInfoOveragePricing",
   "StorageLimitResponse",
+  "StorageLimits",
+  "StorageSummary",
   "SubgraphQuotaResponse",
   "SubgraphResponse",
   "SubgraphResponseMetadataType0",
   "SubgraphSummary",
   "SubgraphType",
-  "SubscriptionInfo",
-  "SubscriptionInfoMetadata",
-  "SubscriptionRequest",
-  "SubscriptionResponse",
   "SuccessResponse",
   "SuccessResponseDataType0",
   "SyncConnectionRequest",
   "SyncConnectionRequestSyncOptionsType0",
   "SyncConnectionResponseSyncconnection",
-  "TierUpgradeRequest",
+  "TableInfo",
+  "TableIngestResult",
+  "TableListResponse",
+  "TableQueryRequest",
+  "TableQueryResponse",
+  "TokenPricing",
   "TransactionSummaryResponse",
   "UpdateAPIKeyRequest",
+  "UpdateFileStatusResponseUpdatefilestatus",
   "UpdatePasswordRequest",
   "UpdateUserRequest",
-  "URLCopyRequest",
-  "URLCopyRequestFileFormat",
-  "URLCopyRequestHeadersType0",
-  "UserAnalyticsResponse",
-  "UserAnalyticsResponseApiUsage",
-  "UserAnalyticsResponseGraphUsage",
-  "UserAnalyticsResponseLimits",
-  "UserAnalyticsResponseRecentActivityItem",
-  "UserAnalyticsResponseUserInfo",
+  "UpgradeSubscriptionRequest",
   "UserGraphsResponse",
-  "UserGraphSummary",
   "UserLimitsResponse",
   "UserResponse",
-  "UserSubscriptionsResponse",
   "UserUsageResponse",
   "UserUsageResponseGraphs",
-  "UserUsageSummaryResponse",
-  "UserUsageSummaryResponseUsageVsLimits",
   "ValidationError",
 )
