@@ -9,12 +9,7 @@ T = TypeVar("T", bound="CustomSchemaDefinitionMetadata")
 
 @_attrs_define
 class CustomSchemaDefinitionMetadata:
-  """Additional schema metadata
-
-  Example:
-      {'created_by': 'inventory_team', 'industry': 'retail'}
-
-  """
+  """Additional schema metadata"""
 
   additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)
 
